# -*- coding: utf-8 -*-

import string
from charguana import get_charset

punctuations = set(list(string.punctuation) +
                 list(get_charset('Currency_Symbol')) +
                 list(get_charset('Close_Punctuation')) +
                 list(get_charset('Open_Punctuation')) +
                 list(get_charset('punctuation')))

# From https://raw.githubusercontent.com/6/stopwords-json/master/stopwords-all.json
stopwords = {"af":[u"'n",u"aan",u"af",u"al",u"as",u"baie",u"by",u"daar",u"dag",u"dat",u"die",u"dit",u"een",u"ek",u"en",u"gaan",u"gesê",u"haar",u"het",u"hom",u"hulle",u"hy",u"in",u"is",u"jou",u"jy",u"kan",u"kom",u"ma",u"maar",u"met",u"my",u"na",u"nie",u"om",u"ons",u"op",u"saam",u"sal",u"se",u"sien",u"so",u"sy",u"te",u"toe",u"uit",u"van",u"vir",u"was",u"wat",u"ŉ"],u"ha":[u"a",u"amma",u"ba",u"ban",u"ce",u"cikin",u"da",u"don",u"ga",u"in",u"ina",u"ita",u"ji",u"ka",u"ko",u"kuma",u"lokacin",u"ma",u"mai",u"na",u"ne",u"ni",u"sai",u"shi",u"su",u"suka",u"sun",u"ta",u"tafi",u"take",u"tana",u"wani",u"wannan",u"wata",u"ya",u"yake",u"yana",u"yi",u"za"],u"so":[u"aad",u"albaabkii",u"atabo",u"ay",u"ayaa",u"ayee",u"ayuu",u"dhan",u"hadana",u"in",u"inuu",u"isku",u"jiray",u"jirtay",u"ka",u"kale",u"kasoo",u"ku",u"kuu",u"lakin",u"markii",u"oo",u"si",u"soo",u"uga",u"ugu",u"uu",u"waa",u"waxa",u"waxuu"],u"st":[u"a",u"ba",u"bane",u"bona",u"e",u"ea",u"eaba",u"empa",u"ena",u"ha",u"hae",u"hape",u"ho",u"hore",u"ka",u"ke",u"la",u"le",u"li",u"me",u"mo",u"moo",u"ne",u"o",u"oa",u"re",u"sa",u"se",u"tloha",u"tsa",u"tse"],u"sw":[u"akasema",u"alikuwa",u"alisema",u"baada",u"basi",u"bila",u"cha",u"chini",u"hadi",u"hapo",u"hata",u"hivyo",u"hiyo",u"huku",u"huo",u"ili",u"ilikuwa",u"juu",u"kama",u"karibu",u"katika",u"kila",u"kima",u"kisha",u"kubwa",u"kutoka",u"kuwa",u"kwa",u"kwamba",u"kwenda",u"kwenye",u"la",u"lakini",u"mara",u"mdogo",u"mimi",u"mkubwa",u"mmoja",u"moja",u"muda",u"mwenye",u"na",u"naye",u"ndani",u"ng",u"ni",u"nini",u"nonkungu",u"pamoja",u"pia",u"sana",u"sasa",u"sauti",u"tafadhali",u"tena",u"tu",u"vile",u"wa",u"wakati",u"wake",u"walikuwa",u"wao",u"watu",u"wengine",u"wote",u"ya",u"yake",u"yangu",u"yao",u"yeye",u"yule",u"za",u"zaidi",u"zake"],u"yo":[u"a",u"an",u"bá",u"bí",u"bẹ̀rẹ̀",u"fún",u"fẹ́",u"gbogbo",u"inú",u"jù",u"jẹ",u"jẹ́",u"kan",u"kì",u"kí",u"kò",u"láti",u"lè",u"lọ",u"mi",u"mo",u"máa",u"mọ̀",u"ni",u"náà",u"ní",u"nígbà",u"nítorí",u"nǹkan",u"o",u"padà",u"pé",u"púpọ̀",u"pẹ̀lú",u"rẹ̀",u"sì",u"sí",u"sínú",u"ṣ",u"ti",u"tí",u"wà",u"wá",u"wọn",u"wọ́n",u"yìí",u"àti",u"àwọn",u"é",u"í",u"òun",u"ó",u"ń",u"ńlá",u"ṣe",u"ṣé",u"ṣùgbọ́n",u"ẹmọ́",u"ọjọ́",u"ọ̀pọ̀lọpọ̀"],u"zu":[u"futhi",u"kahle",u"kakhulu",u"kanye",u"khona",u"kodwa",u"kungani",u"kusho",u"la",u"lakhe",u"lapho",u"mina",u"ngesikhathi",u"nje",u"phansi",u"phezulu",u"u",u"ukuba",u"ukuthi",u"ukuze",u"uma",u"wahamba",u"wakhe",u"wami",u"wase",u"wathi",u"yakhe",u"zakhe",u"zonke"],u"da":[u"af",u"alle",u"andet",u"andre",u"at",u"begge",u"da",u"de",u"den",u"denne",u"der",u"deres",u"det",u"dette",u"dig",u"din",u"dog",u"du",u"ej",u"eller",u"en",u"end",u"ene",u"eneste",u"enhver",u"et",u"fem",u"fire",u"flere",u"fleste",u"for",u"fordi",u"forrige",u"fra",u"få",u"før",u"god",u"han",u"hans",u"har",u"hendes",u"her",u"hun",u"hvad",u"hvem",u"hver",u"hvilken",u"hvis",u"hvor",u"hvordan",u"hvorfor",u"hvornår",u"i",u"ikke",u"ind",u"ingen",u"intet",u"jeg",u"jeres",u"kan",u"kom",u"kommer",u"lav",u"lidt",u"lille",u"man",u"mand",u"mange",u"med",u"meget",u"men",u"mens",u"mere",u"mig",u"ned",u"ni",u"nogen",u"noget",u"ny",u"nyt",u"nær",u"næste",u"næsten",u"og",u"op",u"otte",u"over",u"på",u"se",u"seks",u"ses",u"som",u"stor",u"store",u"syv",u"ti",u"til",u"to",u"tre",u"ud",u"var"],u"de":[u"Ernst",u"Ordnung",u"Schluss",u"a",u"ab",u"aber",u"ach",u"acht",u"achte",u"achten",u"achter",u"achtes",u"ag",u"alle",u"allein",u"allem",u"allen",u"aller",u"allerdings",u"alles",u"allgemeinen",u"als",u"also",u"am",u"an",u"andere",u"anderen",u"andern",u"anders",u"au",u"auch",u"auf",u"aus",u"ausser",u"ausserdem",u"außer",u"außerdem",u"b",u"bald",u"bei",u"beide",u"beiden",u"beim",u"beispiel",u"bekannt",u"bereits",u"besonders",u"besser",u"besten",u"bin",u"bis",u"bisher",u"bist",u"c",u"d",u"d.h",u"da",u"dabei",u"dadurch",u"dafür",u"dagegen",u"daher",u"dahin",u"dahinter",u"damals",u"damit",u"danach",u"daneben",u"dank",u"dann",u"daran",u"darauf",u"daraus",u"darf",u"darfst",u"darin",u"darum",u"darunter",u"darüber",u"das",u"dasein",u"daselbst",u"dass",u"dasselbe",u"davon",u"davor",u"dazu",u"dazwischen",u"daß",u"dein",u"deine",u"deinem",u"deiner",u"dem",u"dementsprechend",u"demgegenüber",u"demgemäss",u"demgemäß",u"demselben",u"demzufolge",u"den",u"denen",u"denn",u"denselben",u"der",u"deren",u"derjenige",u"derjenigen",u"dermassen",u"dermaßen",u"derselbe",u"derselben",u"des",u"deshalb",u"desselben",u"dessen",u"deswegen",u"dich",u"die",u"diejenige",u"diejenigen",u"dies",u"diese",u"dieselbe",u"dieselben",u"diesem",u"diesen",u"dieser",u"dieses",u"dir",u"doch",u"dort",u"drei",u"drin",u"dritte",u"dritten",u"dritter",u"drittes",u"du",u"durch",u"durchaus",u"durfte",u"durften",u"dürfen",u"dürft",u"e",u"eben",u"ebenso",u"ehrlich",u"ei",u"ei,u",u"eigen",u"eigene",u"eigenen",u"eigener",u"eigenes",u"ein",u"einander",u"eine",u"einem",u"einen",u"einer",u"eines",u"einige",u"einigen",u"einiger",u"einiges",u"einmal",u"eins",u"elf",u"en",u"ende",u"endlich",u"entweder",u"er",u"erst",u"erste",u"ersten",u"erster",u"erstes",u"es",u"etwa",u"etwas",u"euch",u"euer",u"eure",u"f",u"folgende",u"früher",u"fünf",u"fünfte",u"fünften",u"fünfter",u"fünftes",u"für",u"g",u"gab",u"ganz",u"ganze",u"ganzen",u"ganzer",u"ganzes",u"gar",u"gedurft",u"gegen",u"gegenüber",u"gehabt",u"gehen",u"geht",u"gekannt",u"gekonnt",u"gemacht",u"gemocht",u"gemusst",u"genug",u"gerade",u"gern",u"gesagt",u"geschweige",u"gewesen",u"gewollt",u"geworden",u"gibt",u"ging",u"gleich",u"gott",u"gross",u"grosse",u"grossen",u"grosser",u"grosses",u"groß",u"große",u"großen",u"großer",u"großes",u"gut",u"gute",u"guter",u"gutes",u"h",u"habe",u"haben",u"habt",u"hast",u"hat",u"hatte",u"hatten",u"hattest",u"hattet",u"heisst",u"her",u"heute",u"hier",u"hin",u"hinter",u"hoch",u"hätte",u"hätten",u"i",u"ich",u"ihm",u"ihn",u"ihnen",u"ihr",u"ihre",u"ihrem",u"ihren",u"ihrer",u"ihres",u"im",u"immer",u"in",u"indem",u"infolgedessen",u"ins",u"irgend",u"ist",u"j",u"ja",u"jahr",u"jahre",u"jahren",u"je",u"jede",u"jedem",u"jeden",u"jeder",u"jedermann",u"jedermanns",u"jedes",u"jedoch",u"jemand",u"jemandem",u"jemanden",u"jene",u"jenem",u"jenen",u"jener",u"jenes",u"jetzt",u"k",u"kam",u"kann",u"kannst",u"kaum",u"kein",u"keine",u"keinem",u"keinen",u"keiner",u"kleine",u"kleinen",u"kleiner",u"kleines",u"kommen",u"kommt",u"konnte",u"konnten",u"kurz",u"können",u"könnt",u"könnte",u"l",u"lang",u"lange",u"leicht",u"leide",u"lieber",u"los",u"m",u"machen",u"macht",u"machte",u"mag",u"magst",u"mahn",u"mal",u"man",u"manche",u"manchem",u"manchen",u"mancher",u"manches",u"mann",u"mehr",u"mein",u"meine",u"meinem",u"meinen",u"meiner",u"meines",u"mensch",u"menschen",u"mich",u"mir",u"mit",u"mittel",u"mochte",u"mochten",u"morgen",u"muss",u"musst",u"musste",u"mussten",u"muß",u"mußt",u"möchte",u"mögen",u"möglich",u"mögt",u"müssen",u"müsst",u"müßt",u"n",u"na",u"nach",u"nachdem",u"nahm",u"natürlich",u"neben",u"nein",u"neue",u"neuen",u"neun",u"neunte",u"neunten",u"neunter",u"neuntes",u"nicht",u"nichts",u"nie",u"niemand",u"niemandem",u"niemanden",u"noch",u"nun",u"nur",u"o",u"ob",u"oben",u"oder",u"offen",u"oft",u"ohne",u"p",u"q",u"r",u"recht",u"rechte",u"rechten",u"rechter",u"rechtes",u"richtig",u"rund",u"s",u"sa",u"sache",u"sagt",u"sagte",u"sah",u"satt",u"schlecht",u"schon",u"sechs",u"sechste",u"sechsten",u"sechster",u"sechstes",u"sehr",u"sei",u"seid",u"seien",u"sein",u"seine",u"seinem",u"seinen",u"seiner",u"seines",u"seit",u"seitdem",u"selbst",u"sich",u"sie",u"sieben",u"siebente",u"siebenten",u"siebenter",u"siebentes",u"sind",u"so",u"solang",u"solche",u"solchem",u"solchen",u"solcher",u"solches",u"soll",u"sollen",u"sollst",u"sollt",u"sollte",u"sollten",u"sondern",u"sonst",u"soweit",u"sowie",u"später",u"startseite",u"statt",u"steht",u"suche",u"t",u"tag",u"tage",u"tagen",u"tat",u"teil",u"tel",u"tritt",u"trotzdem",u"tun",u"u",u"uhr",u"um",u"und",u"und?",u"uns",u"unser",u"unsere",u"unserer",u"unter",u"v",u"vergangenen",u"viel",u"viele",u"vielem",u"vielen",u"vielleicht",u"vier",u"vierte",u"vierten",u"vierter",u"viertes",u"vom",u"von",u"vor",u"w",u"wahr?",u"wann",u"war",u"waren",u"wart",u"warum",u"was",u"wegen",u"weil",u"weit",u"weiter",u"weitere",u"weiteren",u"weiteres",u"welche",u"welchem",u"welchen",u"welcher",u"welches",u"wem",u"wen",u"wenig",u"wenige",u"weniger",u"weniges",u"wenigstens",u"wenn",u"wer",u"werde",u"werden",u"werdet",u"weshalb",u"wessen",u"wie",u"wieder",u"wieso",u"will",u"willst",u"wir",u"wird",u"wirklich",u"wirst",u"wissen",u"wo",u"wohl",u"wollen",u"wollt",u"wollte",u"wollten",u"worden",u"wurde",u"wurden",u"während",u"währenddem",u"währenddessen",u"wäre",u"würde",u"würden",u"x",u"y",u"z",u"z.b",u"zehn",u"zehnte",u"zehnten",u"zehnter",u"zehntes",u"zeit",u"zu",u"zuerst",u"zugleich",u"zum",u"zunächst",u"zur",u"zurück",u"zusammen",u"zwanzig",u"zwar",u"zwei",u"zweite",u"zweiten",u"zweiter",u"zweites",u"zwischen",u"zwölf",u"über",u"überhaupt",u"übrigens"],u"es":[u"a",u"actualmente",u"acuerdo",u"adelante",u"ademas",u"además",u"adrede",u"afirmó",u"agregó",u"ahi",u"ahora",u"ahí",u"al",u"algo",u"alguna",u"algunas",u"alguno",u"algunos",u"algún",u"alli",u"allí",u"alrededor",u"ambos",u"ampleamos",u"antano",u"antaño",u"ante",u"anterior",u"antes",u"apenas",u"aproximadamente",u"aquel",u"aquella",u"aquellas",u"aquello",u"aquellos",u"aqui",u"aquél",u"aquélla",u"aquéllas",u"aquéllos",u"aquí",u"arriba",u"arribaabajo",u"aseguró",u"asi",u"así",u"atras",u"aun",u"aunque",u"ayer",u"añadió",u"aún",u"b",u"bajo",u"bastante",u"bien",u"breve",u"buen",u"buena",u"buenas",u"bueno",u"buenos",u"c",u"cada",u"casi",u"cerca",u"cierta",u"ciertas",u"cierto",u"ciertos",u"cinco",u"claro",u"comentó",u"como",u"con",u"conmigo",u"conocer",u"conseguimos",u"conseguir",u"considera",u"consideró",u"consigo",u"consigue",u"consiguen",u"consigues",u"contigo",u"contra",u"cosas",u"creo",u"cual",u"cuales",u"cualquier",u"cuando",u"cuanta",u"cuantas",u"cuanto",u"cuantos",u"cuatro",u"cuenta",u"cuál",u"cuáles",u"cuándo",u"cuánta",u"cuántas",u"cuánto",u"cuántos",u"cómo",u"d",u"da",u"dado",u"dan",u"dar",u"de",u"debajo",u"debe",u"deben",u"debido",u"decir",u"dejó",u"del",u"delante",u"demasiado",u"demás",u"dentro",u"deprisa",u"desde",u"despacio",u"despues",u"después",u"detras",u"detrás",u"dia",u"dias",u"dice",u"dicen",u"dicho",u"dieron",u"diferente",u"diferentes",u"dijeron",u"dijo",u"dio",u"donde",u"dos",u"durante",u"día",u"días",u"dónde",u"e",u"ejemplo",u"el",u"ella",u"ellas",u"ello",u"ellos",u"embargo",u"empleais",u"emplean",u"emplear",u"empleas",u"empleo",u"en",u"encima",u"encuentra",u"enfrente",u"enseguida",u"entonces",u"entre",u"era",u"eramos",u"eran",u"eras",u"eres",u"es",u"esa",u"esas",u"ese",u"eso",u"esos",u"esta",u"estaba",u"estaban",u"estado",u"estados",u"estais",u"estamos",u"estan",u"estar",u"estará",u"estas",u"este",u"esto",u"estos",u"estoy",u"estuvo",u"está",u"están",u"ex",u"excepto",u"existe",u"existen",u"explicó",u"expresó",u"f",u"fin",u"final",u"fue",u"fuera",u"fueron",u"fui",u"fuimos",u"g",u"general",u"gran",u"grandes",u"gueno",u"h",u"ha",u"haber",u"habia",u"habla",u"hablan",u"habrá",u"había",u"habían",u"hace",u"haceis",u"hacemos",u"hacen",u"hacer",u"hacerlo",u"haces",u"hacia",u"haciendo",u"hago",u"han",u"hasta",u"hay",u"haya",u"he",u"hecho",u"hemos",u"hicieron",u"hizo",u"horas",u"hoy",u"hubo",u"i",u"igual",u"incluso",u"indicó",u"informo",u"informó",u"intenta",u"intentais",u"intentamos",u"intentan",u"intentar",u"intentas",u"intento",u"ir",u"j",u"junto",u"k",u"l",u"la",u"lado",u"largo",u"las",u"le",u"lejos",u"les",u"llegó",u"lleva",u"llevar",u"lo",u"los",u"luego",u"lugar",u"m",u"mal",u"manera",u"manifestó",u"mas",u"mayor",u"me",u"mediante",u"medio",u"mejor",u"mencionó",u"menos",u"menudo",u"mi",u"mia",u"mias",u"mientras",u"mio",u"mios",u"mis",u"misma",u"mismas",u"mismo",u"mismos",u"modo",u"momento",u"mucha",u"muchas",u"mucho",u"muchos",u"muy",u"más",u"mí",u"mía",u"mías",u"mío",u"míos",u"n",u"nada",u"nadie",u"ni",u"ninguna",u"ningunas",u"ninguno",u"ningunos",u"ningún",u"no",u"nos",u"nosotras",u"nosotros",u"nuestra",u"nuestras",u"nuestro",u"nuestros",u"nueva",u"nuevas",u"nuevo",u"nuevos",u"nunca",u"o",u"ocho",u"os",u"otra",u"otras",u"otro",u"otros",u"p",u"pais",u"para",u"parece",u"parte",u"partir",u"pasada",u"pasado",u"paìs",u"peor",u"pero",u"pesar",u"poca",u"pocas",u"poco",u"pocos",u"podeis",u"podemos",u"poder",u"podria",u"podriais",u"podriamos",u"podrian",u"podrias",u"podrá",u"podrán",u"podría",u"podrían",u"poner",u"por",u"porque",u"posible",u"primer",u"primera",u"primero",u"primeros",u"principalmente",u"pronto",u"propia",u"propias",u"propio",u"propios",u"proximo",u"próximo",u"próximos",u"pudo",u"pueda",u"puede",u"pueden",u"puedo",u"pues",u"q",u"qeu",u"que",u"quedó",u"queremos",u"quien",u"quienes",u"quiere",u"quiza",u"quizas",u"quizá",u"quizás",u"quién",u"quiénes",u"qué",u"r",u"raras",u"realizado",u"realizar",u"realizó",u"repente",u"respecto",u"s",u"sabe",u"sabeis",u"sabemos",u"saben",u"saber",u"sabes",u"salvo",u"se",u"sea",u"sean",u"segun",u"segunda",u"segundo",u"según",u"seis",u"ser",u"sera",u"será",u"serán",u"sería",u"señaló",u"si",u"sido",u"siempre",u"siendo",u"siete",u"sigue",u"siguiente",u"sin",u"sino",u"sobre",u"sois",u"sola",u"solamente",u"solas",u"solo",u"solos",u"somos",u"son",u"soy",u"soyos",u"su",u"supuesto",u"sus",u"suya",u"suyas",u"suyo",u"sé",u"sí",u"sólo",u"t",u"tal",u"tambien",u"también",u"tampoco",u"tan",u"tanto",u"tarde",u"te",u"temprano",u"tendrá",u"tendrán",u"teneis",u"tenemos",u"tener",u"tenga",u"tengo",u"tenido",u"tenía",u"tercera",u"ti",u"tiempo",u"tiene",u"tienen",u"toda",u"todas",u"todavia",u"todavía",u"todo",u"todos",u"total",u"trabaja",u"trabajais",u"trabajamos",u"trabajan",u"trabajar",u"trabajas",u"trabajo",u"tras",u"trata",u"través",u"tres",u"tu",u"tus",u"tuvo",u"tuya",u"tuyas",u"tuyo",u"tuyos",u"tú",u"u",u"ultimo",u"un",u"una",u"unas",u"uno",u"unos",u"usa",u"usais",u"usamos",u"usan",u"usar",u"usas",u"uso",u"usted",u"ustedes",u"v",u"va",u"vais",u"valor",u"vamos",u"van",u"varias",u"varios",u"vaya",u"veces",u"ver",u"verdad",u"verdadera",u"verdadero",u"vez",u"vosotras",u"vosotros",u"voy",u"vuestra",u"vuestras",u"vuestro",u"vuestros",u"w",u"x",u"y",u"ya",u"yo",u"z",u"él",u"ésa",u"ésas",u"ése",u"ésos",u"ésta",u"éstas",u"éste",u"éstos",u"última",u"últimas",u"último",u"últimos"],u"et":[u"aga",u"ei",u"et",u"ja",u"jah",u"kas",u"kui",u"kõik",u"ma",u"me",u"mida",u"midagi",u"mind",u"minu",u"mis",u"mu",u"mul",u"mulle",u"nad",u"nii",u"oled",u"olen",u"oli",u"oma",u"on",u"pole",u"sa",u"seda",u"see",u"selle",u"siin",u"siis",u"ta",u"te",u"ära"],u"fi":[u"aiemmin",u"aika",u"aikaa",u"aikaan",u"aikaisemmin",u"aikaisin",u"aikajen",u"aikana",u"aikoina",u"aikoo",u"aikovat",u"aina",u"ainakaan",u"ainakin",u"ainoa",u"ainoat",u"aiomme",u"aion",u"aiotte",u"aist",u"aivan",u"ajan",u"alas",u"alemmas",u"alkuisin",u"alkuun",u"alla",u"alle",u"aloitamme",u"aloitan",u"aloitat",u"aloitatte",u"aloitattivat",u"aloitettava",u"aloitettevaksi",u"aloitettu",u"aloitimme",u"aloitin",u"aloitit",u"aloititte",u"aloittaa",u"aloittamatta",u"aloitti",u"aloittivat",u"alta",u"aluksi",u"alussa",u"alusta",u"annettavaksi",u"annetteva",u"annettu",u"ansiosta",u"antaa",u"antamatta",u"antoi",u"aoua",u"apu",u"asia",u"asiaa",u"asian",u"asiasta",u"asiat",u"asioiden",u"asioihin",u"asioita",u"asti",u"avuksi",u"avulla",u"avun",u"avutta",u"edelle",u"edelleen",u"edellä",u"edeltä",u"edemmäs",u"edes",u"edessä",u"edestä",u"ehkä",u"ei",u"eikä",u"eilen",u"eivät",u"eli",u"ellei",u"elleivät",u"ellemme",u"ellen",u"ellet",u"ellette",u"emme",u"en",u"enemmän",u"eniten",u"ennen",u"ensi",u"ensimmäinen",u"ensimmäiseksi",u"ensimmäisen",u"ensimmäisenä",u"ensimmäiset",u"ensimmäisiksi",u"ensimmäisinä",u"ensimmäisiä",u"ensimmäistä",u"ensin",u"entinen",u"entisen",u"entisiä",u"entisten",u"entistä",u"enää",u"eri",u"erittäin",u"erityisesti",u"eräiden",u"eräs",u"eräät",u"esi",u"esiin",u"esillä",u"esimerkiksi",u"et",u"eteen",u"etenkin",u"etessa",u"ette",u"ettei",u"että",u"haikki",u"halua",u"haluaa",u"haluamatta",u"haluamme",u"haluan",u"haluat",u"haluatte",u"haluavat",u"halunnut",u"halusi",u"halusimme",u"halusin",u"halusit",u"halusitte",u"halusivat",u"halutessa",u"haluton",u"he",u"hei",u"heidän",u"heihin",u"heille",u"heiltä",u"heissä",u"heistä",u"heitä",u"helposti",u"heti",u"hetkellä",u"hieman",u"hitaasti",u"hoikein",u"huolimatta",u"huomenna",u"hyvien",u"hyviin",u"hyviksi",u"hyville",u"hyviltä",u"hyvin",u"hyvinä",u"hyvissä",u"hyvistä",u"hyviä",u"hyvä",u"hyvät",u"hyvää",u"hän",u"häneen",u"hänelle",u"hänellä",u"häneltä",u"hänen",u"hänessä",u"hänestä",u"hänet",u"ihan",u"ilman",u"ilmeisesti",u"itse",u"itsensä",u"itseään",u"ja",u"jo",u"johon",u"joiden",u"joihin",u"joiksi",u"joilla",u"joille",u"joilta",u"joissa",u"joista",u"joita",u"joka",u"jokainen",u"jokin",u"joko",u"joku",u"jolla",u"jolle",u"jolloin",u"jolta",u"jompikumpi",u"jonka",u"jonkin",u"jonne",u"joo",u"jopa",u"jos",u"joskus",u"jossa",u"josta",u"jota",u"jotain",u"joten",u"jotenkin",u"jotenkuten",u"jotka",u"jotta",u"jouduimme",u"jouduin",u"jouduit",u"jouduitte",u"joudumme",u"joudun",u"joudutte",u"joukkoon",u"joukossa",u"joukosta",u"joutua",u"joutui",u"joutuivat",u"joutumaan",u"joutuu",u"joutuvat",u"juuri",u"jälkeen",u"jälleen",u"jää",u"kahdeksan",u"kahdeksannen",u"kahdella",u"kahdelle",u"kahdelta",u"kahden",u"kahdessa",u"kahdesta",u"kahta",u"kahteen",u"kai",u"kaiken",u"kaikille",u"kaikilta",u"kaikkea",u"kaikki",u"kaikkia",u"kaikkiaan",u"kaikkialla",u"kaikkialle",u"kaikkialta",u"kaikkien",u"kaikkin",u"kaksi",u"kannalta",u"kannattaa",u"kanssa",u"kanssaan",u"kanssamme",u"kanssani",u"kanssanne",u"kanssasi",u"kauan",u"kauemmas",u"kaukana",u"kautta",u"kehen",u"keiden",u"keihin",u"keiksi",u"keille",u"keillä",u"keiltä",u"keinä",u"keissä",u"keistä",u"keitten",u"keittä",u"keitä",u"keneen",u"keneksi",u"kenelle",u"kenellä",u"keneltä",u"kenen",u"kenenä",u"kenessä",u"kenestä",u"kenet",u"kenettä",u"kennessästä",u"kenties",u"kerran",u"kerta",u"kertaa",u"keskellä",u"kesken",u"keskimäärin",u"ketkä",u"ketä",u"kiitos",u"kohti",u"koko",u"kokonaan",u"kolmas",u"kolme",u"kolmen",u"kolmesti",u"koska",u"koskaan",u"kovin",u"kuin",u"kuinka",u"kuinkan",u"kuitenkaan",u"kuitenkin",u"kuka",u"kukaan",u"kukin",u"kukka",u"kumpainen",u"kumpainenkaan",u"kumpi",u"kumpikaan",u"kumpikin",u"kun",u"kuten",u"kuuden",u"kuusi",u"kuutta",u"kylliksi",u"kyllä",u"kymmenen",u"kyse",u"liian",u"liki",u"lisäksi",u"lisää",u"lla",u"luo",u"luona",u"lähekkäin",u"lähelle",u"lähellä",u"läheltä",u"lähemmäs",u"lähes",u"lähinnä",u"lähtien",u"läpi",u"mahdollisimman",u"mahdollista",u"me",u"meidän",u"meille",u"meillä",u"melkein",u"melko",u"menee",u"meneet",u"menemme",u"menen",u"menet",u"menette",u"menevät",u"meni",u"menimme",u"menin",u"menit",u"menivät",u"mennessä",u"mennyt",u"menossa",u"mihin",u"mikin",u"miksi",u"mikä",u"mikäli",u"mikään",u"milloin",u"milloinkan",u"minne",u"minun",u"minut",u"minä",u"missä",u"mistä",u"miten",u"mitä",u"mitään",u"moi",u"molemmat",u"mones",u"monesti",u"monet",u"moni",u"moniaalla",u"moniaalle",u"moniaalta",u"monta",u"muassa",u"muiden",u"muita",u"muka",u"mukaan",u"mukaansa",u"mukana",u"mutta",u"muu",u"muualla",u"muualle",u"muualta",u"muuanne",u"muulloin",u"muun",u"muut",u"muuta",u"muutama",u"muutaman",u"muuten",u"myöhemmin",u"myös",u"myöskin",u"myöskään",u"myötä",u"ne",u"neljä",u"neljän",u"neljää",u"niiden",u"niin",u"niistä",u"niitä",u"noin",u"nopeammin",u"nopeasti",u"nopeiten",u"nro",u"nuo",u"nyt",u"näiden",u"näin",u"näissä",u"näissähin",u"näissälle",u"näissältä",u"näissästä",u"näitä",u"nämä",u"ohi",u"oikea",u"oikealla",u"oikein",u"ole",u"olemme",u"olen",u"olet",u"olette",u"oleva",u"olevan",u"olevat",u"oli",u"olimme",u"olin",u"olisi",u"olisimme",u"olisin",u"olisit",u"olisitte",u"olisivat",u"olit",u"olitte",u"olivat",u"olla",u"olleet",u"olli",u"ollut",u"oma",u"omaa",u"omaan",u"omaksi",u"omalle",u"omalta",u"oman",u"omassa",u"omat",u"omia",u"omien",u"omiin",u"omiksi",u"omille",u"omilta",u"omissa",u"omista",u"on",u"onkin",u"onko",u"ovat",u"paikoittain",u"paitsi",u"pakosti",u"paljon",u"paremmin",u"parempi",u"parhaillaan",u"parhaiten",u"perusteella",u"peräti",u"pian",u"pieneen",u"pieneksi",u"pienelle",u"pienellä",u"pieneltä",u"pienempi",u"pienestä",u"pieni",u"pienin",u"puolesta",u"puolestaan",u"päälle",u"runsaasti",u"saakka",u"sadam",u"sama",u"samaa",u"samaan",u"samalla",u"samallalta",u"samallassa",u"samallasta",u"saman",u"samat",u"samoin",u"sata",u"sataa",u"satojen",u"se",u"seitsemän",u"sekä",u"sen",u"seuraavat",u"siellä",u"sieltä",u"siihen",u"siinä",u"siis",u"siitä",u"sijaan",u"siksi",u"silloin",u"sillä",u"silti",u"sinne",u"sinua",u"sinulle",u"sinulta",u"sinun",u"sinussa",u"sinusta",u"sinut",u"sinä",u"sisäkkäin",u"sisällä",u"siten",u"sitten",u"sitä",u"ssa",u"sta",u"suoraan",u"suuntaan",u"suuren",u"suuret",u"suuri",u"suuria",u"suurin",u"suurten",u"taa",u"taas",u"taemmas",u"tahansa",u"tai",u"takaa",u"takaisin",u"takana",u"takia",u"tapauksessa",u"tarpeeksi",u"tavalla",u"tavoitteena",u"te",u"tietysti",u"todella",u"toinen",u"toisaalla",u"toisaalle",u"toisaalta",u"toiseen",u"toiseksi",u"toisella",u"toiselle",u"toiselta",u"toisemme",u"toisen",u"toisensa",u"toisessa",u"toisesta",u"toista",u"toistaiseksi",u"toki",u"tosin",u"tuhannen",u"tuhat",u"tule",u"tulee",u"tulemme",u"tulen",u"tulet",u"tulette",u"tulevat",u"tulimme",u"tulin",u"tulisi",u"tulisimme",u"tulisin",u"tulisit",u"tulisitte",u"tulisivat",u"tulit",u"tulitte",u"tulivat",u"tulla",u"tulleet",u"tullut",u"tuntuu",u"tuo",u"tuolla",u"tuolloin",u"tuolta",u"tuonne",u"tuskin",u"tykö",u"tähän",u"tällä",u"tällöin",u"tämä",u"tämän",u"tänne",u"tänä",u"tänään",u"tässä",u"tästä",u"täten",u"tätä",u"täysin",u"täytyvät",u"täytyy",u"täällä",u"täältä",u"ulkopuolella",u"usea",u"useasti",u"useimmiten",u"usein",u"useita",u"uudeksi",u"uudelleen",u"uuden",u"uudet",u"uusi",u"uusia",u"uusien",u"uusinta",u"uuteen",u"uutta",u"vaan",u"vahemmän",u"vai",u"vaiheessa",u"vaikea",u"vaikean",u"vaikeat",u"vaikeilla",u"vaikeille",u"vaikeilta",u"vaikeissa",u"vaikeista",u"vaikka",u"vain",u"varmasti",u"varsin",u"varsinkin",u"varten",u"vasen",u"vasenmalla",u"vasta",u"vastaan",u"vastakkain",u"vastan",u"verran",u"vielä",u"vierekkäin",u"vieressä",u"vieri",u"viiden",u"viime",u"viimeinen",u"viimeisen",u"viimeksi",u"viisi",u"voi",u"voidaan",u"voimme",u"voin",u"voisi",u"voit",u"voitte",u"voivat",u"vuoden",u"vuoksi",u"vuosi",u"vuosien",u"vuosina",u"vuotta",u"vähemmän",u"vähintään",u"vähiten",u"vähän",u"välillä",u"yhdeksän",u"yhden",u"yhdessä",u"yhteen",u"yhteensä",u"yhteydessä",u"yhteyteen",u"yhtä",u"yhtäälle",u"yhtäällä",u"yhtäältä",u"yhtään",u"yhä",u"yksi",u"yksin",u"yksittäin",u"yleensä",u"ylemmäs",u"yli",u"ylös",u"ympäri",u"älköön",u"älä"],u"fr":[u"a",u"abord",u"absolument",u"afin",u"ah",u"ai",u"aie",u"ailleurs",u"ainsi",u"ait",u"allaient",u"allo",u"allons",u"allô",u"alors",u"anterieur",u"anterieure",u"anterieures",u"apres",u"après",u"as",u"assez",u"attendu",u"au",u"aucun",u"aucune",u"aujourd",u"aujourd'hui",u"aupres",u"auquel",u"aura",u"auraient",u"aurait",u"auront",u"aussi",u"autre",u"autrefois",u"autrement",u"autres",u"autrui",u"aux",u"auxquelles",u"auxquels",u"avaient",u"avais",u"avait",u"avant",u"avec",u"avoir",u"avons",u"ayant",u"b",u"bah",u"bas",u"basee",u"bat",u"beau",u"beaucoup",u"bien",u"bigre",u"boum",u"bravo",u"brrr",u"c",u"car",u"ce",u"ceci",u"cela",u"celle",u"celle-ci",u"celle-là",u"celles",u"celles-ci",u"celles-là",u"celui",u"celui-ci",u"celui-là",u"cent",u"cependant",u"certain",u"certaine",u"certaines",u"certains",u"certes",u"ces",u"cet",u"cette",u"ceux",u"ceux-ci",u"ceux-là",u"chacun",u"chacune",u"chaque",u"cher",u"chers",u"chez",u"chiche",u"chut",u"chère",u"chères",u"ci",u"cinq",u"cinquantaine",u"cinquante",u"cinquantième",u"cinquième",u"clac",u"clic",u"combien",u"comme",u"comment",u"comparable",u"comparables",u"compris",u"concernant",u"contre",u"couic",u"crac",u"d",u"da",u"dans",u"de",u"debout",u"dedans",u"dehors",u"deja",u"delà",u"depuis",u"dernier",u"derniere",u"derriere",u"derrière",u"des",u"desormais",u"desquelles",u"desquels",u"dessous",u"dessus",u"deux",u"deuxième",u"deuxièmement",u"devant",u"devers",u"devra",u"different",u"differentes",u"differents",u"différent",u"différente",u"différentes",u"différents",u"dire",u"directe",u"directement",u"dit",u"dite",u"dits",u"divers",u"diverse",u"diverses",u"dix",u"dix-huit",u"dix-neuf",u"dix-sept",u"dixième",u"doit",u"doivent",u"donc",u"dont",u"douze",u"douzième",u"dring",u"du",u"duquel",u"durant",u"dès",u"désormais",u"e",u"effet",u"egale",u"egalement",u"egales",u"eh",u"elle",u"elle-même",u"elles",u"elles-mêmes",u"en",u"encore",u"enfin",u"entre",u"envers",u"environ",u"es",u"est",u"et",u"etant",u"etc",u"etre",u"eu",u"euh",u"eux",u"eux-mêmes",u"exactement",u"excepté",u"extenso",u"exterieur",u"f",u"fais",u"faisaient",u"faisant",u"fait",u"façon",u"feront",u"fi",u"flac",u"floc",u"font",u"g",u"gens",u"h",u"ha",u"hein",u"hem",u"hep",u"hi",u"ho",u"holà",u"hop",u"hormis",u"hors",u"hou",u"houp",u"hue",u"hui",u"huit",u"huitième",u"hum",u"hurrah",u"hé",u"hélas",u"i",u"il",u"ils",u"importe",u"j",u"je",u"jusqu",u"jusque",u"juste",u"k",u"l",u"la",u"laisser",u"laquelle",u"las",u"le",u"lequel",u"les",u"lesquelles",u"lesquels",u"leur",u"leurs",u"longtemps",u"lors",u"lorsque",u"lui",u"lui-meme",u"lui-même",u"là",u"lès",u"m",u"ma",u"maint",u"maintenant",u"mais",u"malgre",u"malgré",u"maximale",u"me",u"meme",u"memes",u"merci",u"mes",u"mien",u"mienne",u"miennes",u"miens",u"mille",u"mince",u"minimale",u"moi",u"moi-meme",u"moi-même",u"moindres",u"moins",u"mon",u"moyennant",u"multiple",u"multiples",u"même",u"mêmes",u"n",u"na",u"naturel",u"naturelle",u"naturelles",u"ne",u"neanmoins",u"necessaire",u"necessairement",u"neuf",u"neuvième",u"ni",u"nombreuses",u"nombreux",u"non",u"nos",u"notamment",u"notre",u"nous",u"nous-mêmes",u"nouveau",u"nul",u"néanmoins",u"nôtre",u"nôtres",u"o",u"oh",u"ohé",u"ollé",u"olé",u"on",u"ont",u"onze",u"onzième",u"ore",u"ou",u"ouf",u"ouias",u"oust",u"ouste",u"outre",u"ouvert",u"ouverte",u"ouverts",u"o|",u"où",u"p",u"paf",u"pan",u"par",u"parce",u"parfois",u"parle",u"parlent",u"parler",u"parmi",u"parseme",u"partant",u"particulier",u"particulière",u"particulièrement",u"pas",u"passé",u"pendant",u"pense",u"permet",u"personne",u"peu",u"peut",u"peuvent",u"peux",u"pff",u"pfft",u"pfut",u"pif",u"pire",u"plein",u"plouf",u"plus",u"plusieurs",u"plutôt",u"possessif",u"possessifs",u"possible",u"possibles",u"pouah",u"pour",u"pourquoi",u"pourrais",u"pourrait",u"pouvait",u"prealable",u"precisement",u"premier",u"première",u"premièrement",u"pres",u"probable",u"probante",u"procedant",u"proche",u"près",u"psitt",u"pu",u"puis",u"puisque",u"pur",u"pure",u"q",u"qu",u"quand",u"quant",u"quant-à-soi",u"quanta",u"quarante",u"quatorze",u"quatre",u"quatre-vingt",u"quatrième",u"quatrièmement",u"que",u"quel",u"quelconque",u"quelle",u"quelles",u"quelqu'un",u"quelque",u"quelques",u"quels",u"qui",u"quiconque",u"quinze",u"quoi",u"quoique",u"r",u"rare",u"rarement",u"rares",u"relative",u"relativement",u"remarquable",u"rend",u"rendre",u"restant",u"reste",u"restent",u"restrictif",u"retour",u"revoici",u"revoilà",u"rien",u"s",u"sa",u"sacrebleu",u"sait",u"sans",u"sapristi",u"sauf",u"se",u"sein",u"seize",u"selon",u"semblable",u"semblaient",u"semble",u"semblent",u"sent",u"sept",u"septième",u"sera",u"seraient",u"serait",u"seront",u"ses",u"seul",u"seule",u"seulement",u"si",u"sien",u"sienne",u"siennes",u"siens",u"sinon",u"six",u"sixième",u"soi",u"soi-même",u"soit",u"soixante",u"son",u"sont",u"sous",u"souvent",u"specifique",u"specifiques",u"speculatif",u"stop",u"strictement",u"subtiles",u"suffisant",u"suffisante",u"suffit",u"suis",u"suit",u"suivant",u"suivante",u"suivantes",u"suivants",u"suivre",u"superpose",u"sur",u"surtout",u"t",u"ta",u"tac",u"tant",u"tardive",u"te",u"tel",u"telle",u"tellement",u"telles",u"tels",u"tenant",u"tend",u"tenir",u"tente",u"tes",u"tic",u"tien",u"tienne",u"tiennes",u"tiens",u"toc",u"toi",u"toi-même",u"ton",u"touchant",u"toujours",u"tous",u"tout",u"toute",u"toutefois",u"toutes",u"treize",u"trente",u"tres",u"trois",u"troisième",u"troisièmement",u"trop",u"très",u"tsoin",u"tsouin",u"tu",u"té",u"u",u"un",u"une",u"unes",u"uniformement",u"unique",u"uniques",u"uns",u"v",u"va",u"vais",u"vas",u"vers",u"via",u"vif",u"vifs",u"vingt",u"vivat",u"vive",u"vives",u"vlan",u"voici",u"voilà",u"vont",u"vos",u"votre",u"vous",u"vous-mêmes",u"vu",u"vé",u"vôtre",u"vôtres",u"w",u"x",u"y",u"z",u"zut",u"à",u"â",u"ça",u"ès",u"étaient",u"étais",u"était",u"étant",u"été",u"être",u"ô"],u"hr":[u"a",u"ako",u"ali",u"bi",u"bih",u"bila",u"bili",u"bilo",u"bio",u"bismo",u"biste",u"biti",u"bumo",u"da",u"do",u"duž",u"ga",u"hoće",u"hoćemo",u"hoćete",u"hoćeš",u"hoću",u"i",u"iako",u"ih",u"ili",u"iz",u"ja",u"je",u"jedna",u"jedne",u"jedno",u"jer",u"jesam",u"jesi",u"jesmo",u"jest",u"jeste",u"jesu",u"jim",u"joj",u"još",u"ju",u"kada",u"kako",u"kao",u"koja",u"koje",u"koji",u"kojima",u"koju",u"kroz",u"li",u"me",u"mene",u"meni",u"mi",u"mimo",u"moj",u"moja",u"moje",u"mu",u"na",u"nad",u"nakon",u"nam",u"nama",u"nas",u"naš",u"naša",u"naše",u"našeg",u"ne",u"nego",u"neka",u"neki",u"nekog",u"neku",u"nema",u"netko",u"neće",u"nećemo",u"nećete",u"nećeš",u"neću",u"nešto",u"ni",u"nije",u"nikoga",u"nikoje",u"nikoju",u"nisam",u"nisi",u"nismo",u"niste",u"nisu",u"njega",u"njegov",u"njegova",u"njegovo",u"njemu",u"njezin",u"njezina",u"njezino",u"njih",u"njihov",u"njihova",u"njihovo",u"njim",u"njima",u"njoj",u"nju",u"no",u"o",u"od",u"odmah",u"on",u"ona",u"oni",u"ono",u"ova",u"pa",u"pak",u"po",u"pod",u"pored",u"prije",u"s",u"sa",u"sam",u"samo",u"se",u"sebe",u"sebi",u"si",u"smo",u"ste",u"su",u"sve",u"svi",u"svog",u"svoj",u"svoja",u"svoje",u"svom",u"ta",u"tada",u"taj",u"tako",u"te",u"tebe",u"tebi",u"ti",u"to",u"toj",u"tome",u"tu",u"tvoj",u"tvoja",u"tvoje",u"u",u"uz",u"vam",u"vama",u"vas",u"vaš",u"vaša",u"vaše",u"već",u"vi",u"vrlo",u"za",u"zar",u"će",u"ćemo",u"ćete",u"ćeš",u"ću",u"što"],u"hu":[u"a",u"abba",u"abban",u"abból",u"addig",u"ahhoz",u"ahogy",u"ahol",u"aki",u"akik",u"akkor",u"akár",u"alapján",u"alatt",u"alatta",u"alattad",u"alattam",u"alattatok",u"alattuk",u"alattunk",u"alá",u"alád",u"alájuk",u"alám",u"alánk",u"alátok",u"alól",u"alóla",u"alólad",u"alólam",u"alólatok",u"alóluk",u"alólunk",u"amely",u"amelybol",u"amelyek",u"amelyekben",u"amelyeket",u"amelyet",u"amelyik",u"amelynek",u"ami",u"amikor",u"amit",u"amolyan",u"amott",u"amíg",u"annak",u"annál",u"arra",u"arról",u"attól",u"az",u"aznap",u"azok",u"azokat",u"azokba",u"azokban",u"azokból",u"azokhoz",u"azokig",u"azokkal",u"azokká",u"azoknak",u"azoknál",u"azokon",u"azokra",u"azokról",u"azoktól",u"azokért",u"azon",u"azonban",u"azonnal",u"azt",u"aztán",u"azután",u"azzal",u"azzá",u"azért",u"bal",u"balra",u"ban",u"be",u"belé",u"beléd",u"beléjük",u"belém",u"belénk",u"belétek",u"belül",u"belőle",u"belőled",u"belőlem",u"belőletek",u"belőlük",u"belőlünk",u"ben",u"benne",u"benned",u"bennem",u"bennetek",u"bennük",u"bennünk",u"bár",u"bárcsak",u"bármilyen",u"búcsú",u"cikk",u"cikkek",u"cikkeket",u"csak",u"csakhogy",u"csupán",u"de",u"dehogy",u"e",u"ebbe",u"ebben",u"ebből",u"eddig",u"egy",u"egyebek",u"egyebet",u"egyedül",u"egyelőre",u"egyes",u"egyet",u"egyetlen",u"egyik",u"egymás",u"egyre",u"egyszerre",u"egyéb",u"együtt",u"egész",u"egészen",u"ehhez",u"ekkor",u"el",u"eleinte",u"ellen",u"ellenes",u"elleni",u"ellenére",u"elmondta",u"első",u"elsők",u"elsősorban",u"elsőt",u"elé",u"eléd",u"elég",u"eléjük",u"elém",u"elénk",u"elétek",u"elő",u"előbb",u"elől",u"előle",u"előled",u"előlem",u"előletek",u"előlük",u"előlünk",u"először",u"előtt",u"előtte",u"előtted",u"előttem",u"előttetek",u"előttük",u"előttünk",u"előző",u"emilyen",u"engem",u"ennek",u"ennyi",u"ennél",u"enyém",u"erre",u"erről",u"esetben",u"ettől",u"ez",u"ezek",u"ezekbe",u"ezekben",u"ezekből",u"ezeken",u"ezeket",u"ezekhez",u"ezekig",u"ezekkel",u"ezekké",u"ezeknek",u"ezeknél",u"ezekre",u"ezekről",u"ezektől",u"ezekért",u"ezen",u"ezentúl",u"ezer",u"ezret",u"ezt",u"ezután",u"ezzel",u"ezzé",u"ezért",u"fel",u"fele",u"felek",u"felet",u"felett",u"felé",u"fent",u"fenti",u"fél",u"fölé",u"gyakran",u"ha",u"halló",u"hamar",u"hanem",u"harmadik",u"harmadikat",u"harminc",u"hat",u"hatodik",u"hatodikat",u"hatot",u"hatvan",u"helyett",u"hetedik",u"hetediket",u"hetet",u"hetven",u"hirtelen",u"hiszen",u"hiába",u"hogy",u"hogyan",u"hol",u"holnap",u"holnapot",u"honnan",u"hova",u"hozzá",u"hozzád",u"hozzájuk",u"hozzám",u"hozzánk",u"hozzátok",u"hurrá",u"huszadik",u"hány",u"hányszor",u"hármat",u"három",u"hát",u"hátha",u"hátulsó",u"hét",u"húsz",u"ide",u"ide-оda",u"idén",u"igazán",u"igen",u"ill",u"illetve",u"ilyen",u"ilyenkor",u"immár",u"inkább",u"is",u"ismét",u"ison",u"itt",u"jelenleg",u"jobban",u"jobbra",u"jó",u"jól",u"jólesik",u"jóval",u"jövőre",u"kell",u"kellene",u"kellett",u"kelljen",u"keressünk",u"keresztül",u"ketten",u"kettő",u"kettőt",u"kevés",u"ki",u"kiben",u"kiből",u"kicsit",u"kicsoda",u"kihez",u"kik",u"kikbe",u"kikben",u"kikből",u"kiken",u"kiket",u"kikhez",u"kikkel",u"kikké",u"kiknek",u"kiknél",u"kikre",u"kikről",u"kiktől",u"kikért",u"kilenc",u"kilencedik",u"kilencediket",u"kilencet",u"kilencven",u"kin",u"kinek",u"kinél",u"kire",u"kiről",u"kit",u"kitől",u"kivel",u"kivé",u"kié",u"kiért",u"korábban",u"képest",u"kérem",u"kérlek",u"kész",u"késő",u"később",u"későn",u"két",u"kétszer",u"kívül",u"körül",u"köszönhetően",u"köszönöm",u"közben",u"közel",u"közepesen",u"közepén",u"közé",u"között",u"közül",u"külön",u"különben",u"különböző",u"különbözőbb",u"különbözőek",u"lassan",u"le",u"legalább",u"legyen",u"lehet",u"lehetetlen",u"lehetett",u"lehetőleg",u"lehetőség",u"lenne",u"lenni",u"lennék",u"lennének",u"lesz",u"leszek",u"lesznek",u"leszünk",u"lett",u"lettek",u"lettem",u"lettünk",u"lévő",u"ma",u"maga",u"magad",u"magam",u"magatokat",u"magukat",u"magunkat",u"magát",u"mai",u"majd",u"majdnem",u"manapság",u"meg",u"megcsinál",u"megcsinálnak",u"megint",u"megvan",u"mellett",u"mellette",u"melletted",u"mellettem",u"mellettetek",u"mellettük",u"mellettünk",u"mellé",u"melléd",u"melléjük",u"mellém",u"mellénk",u"mellétek",u"mellől",u"mellőle",u"mellőled",u"mellőlem",u"mellőletek",u"mellőlük",u"mellőlünk",u"mely",u"melyek",u"melyik",u"mennyi",u"mert",u"mi",u"miatt",u"miatta",u"miattad",u"miattam",u"miattatok",u"miattuk",u"miattunk",u"mibe",u"miben",u"miből",u"mihez",u"mik",u"mikbe",u"mikben",u"mikből",u"miken",u"miket",u"mikhez",u"mikkel",u"mikké",u"miknek",u"miknél",u"mikor",u"mikre",u"mikről",u"miktől",u"mikért",u"milyen",u"min",u"mind",u"mindegyik",u"mindegyiket",u"minden",u"mindenesetre",u"mindenki",u"mindent",u"mindenütt",u"mindig",u"mindketten",u"minek",u"minket",u"mint",u"mintha",u"minél",u"mire",u"miről",u"mit",u"mitől",u"mivel",u"mivé",u"miért",u"mondta",u"most",u"mostanáig",u"már",u"más",u"másik",u"másikat",u"másnap",u"második",u"másodszor",u"mások",u"másokat",u"mást",u"még",u"mégis",u"míg",u"mögé",u"mögéd",u"mögéjük",u"mögém",u"mögénk",u"mögétek",u"mögött",u"mögötte",u"mögötted",u"mögöttem",u"mögöttetek",u"mögöttük",u"mögöttünk",u"mögül",u"mögüle",u"mögüled",u"mögülem",u"mögületek",u"mögülük",u"mögülünk",u"múltkor",u"múlva",u"na",u"nagy",u"nagyobb",u"nagyon",u"naponta",u"napot",u"ne",u"negyedik",u"negyediket",u"negyven",u"neked",u"nekem",u"neki",u"nekik",u"nektek",u"nekünk",u"nem",u"nemcsak",u"nemrég",u"nincs",u"nyolc",u"nyolcadik",u"nyolcadikat",u"nyolcat",u"nyolcvan",u"nála",u"nálad",u"nálam",u"nálatok",u"náluk",u"nálunk",u"négy",u"négyet",u"néha",u"néhány",u"nélkül",u"o",u"oda",u"ok",u"olyan",u"onnan",u"ott",u"pedig",u"persze",u"pár",u"például",u"rajta",u"rajtad",u"rajtam",u"rajtatok",u"rajtuk",u"rajtunk",u"rendben",u"rosszul",u"rá",u"rád",u"rájuk",u"rám",u"ránk",u"rátok",u"régen",u"régóta",u"részére",u"róla",u"rólad",u"rólam",u"rólatok",u"róluk",u"rólunk",u"rögtön",u"s",u"saját",u"se",u"sem",u"semmi",u"semmilyen",u"semmiség",u"senki",u"soha",u"sok",u"sokan",u"sokat",u"sokkal",u"sokszor",u"sokáig",u"során",u"stb.",u"szemben",u"szerbusz",u"szerint",u"szerinte",u"szerinted",u"szerintem",u"szerintetek",u"szerintük",u"szerintünk",u"szervusz",u"szinte",u"számára",u"száz",u"századik",u"százat",u"szépen",u"szét",u"szíves",u"szívesen",u"szíveskedjék",u"sőt",u"talán",u"tavaly",u"te",u"tegnap",u"tegnapelőtt",u"tehát",u"tele",u"teljes",u"tessék",u"ti",u"tied",u"titeket",u"tizedik",u"tizediket",u"tizenegy",u"tizenegyedik",u"tizenhat",u"tizenhárom",u"tizenhét",u"tizenkettedik",u"tizenkettő",u"tizenkilenc",u"tizenkét",u"tizennyolc",u"tizennégy",u"tizenöt",u"tizet",u"tovább",u"további",u"továbbá",u"távol",u"téged",u"tényleg",u"tíz",u"több",u"többi",u"többször",u"túl",u"tőle",u"tőled",u"tőlem",u"tőletek",u"tőlük",u"tőlünk",u"ugyanakkor",u"ugyanez",u"ugyanis",u"ugye",u"urak",u"uram",u"urat",u"utoljára",u"utolsó",u"után",u"utána",u"vagy",u"vagyis",u"vagyok",u"vagytok",u"vagyunk",u"vajon",u"valahol",u"valaki",u"valakit",u"valamelyik",u"valami",u"valamint",u"való",u"van",u"vannak",u"vele",u"veled",u"velem",u"veletek",u"velük",u"velünk",u"vissza",u"viszlát",u"viszont",u"viszontlátásra",u"volna",u"volnának",u"volnék",u"volt",u"voltak",u"voltam",u"voltunk",u"végre",u"végén",u"végül",u"által",u"általában",u"ám",u"át",u"éljen",u"én",u"éppen",u"érte",u"érted",u"értem",u"értetek",u"értük",u"értünk",u"és",u"év",u"évben",u"éve",u"évek",u"éves",u"évi",u"évvel",u"így",u"óta",u"ön",u"önbe",u"önben",u"önből",u"önhöz",u"önnek",u"önnel",u"önnél",u"önre",u"önről",u"önt",u"öntől",u"önért",u"önök",u"önökbe",u"önökben",u"önökből",u"önöket",u"önökhöz",u"önökkel",u"önöknek",u"önöknél",u"önökre",u"önökről",u"önöktől",u"önökért",u"önökön",u"önön",u"össze",u"öt",u"ötven",u"ötödik",u"ötödiket",u"ötöt",u"úgy",u"úgyis",u"úgynevezett",u"új",u"újabb",u"újra",u"úr",u"ő",u"ők",u"őket",u"őt"],u"it":[u"IE",u"a",u"abbastanza",u"abbia",u"abbiamo",u"abbiano",u"abbiate",u"accidenti",u"ad",u"adesso",u"affinche",u"agl",u"agli",u"ahime",u"ahimè",u"ai",u"al",u"alcuna",u"alcuni",u"alcuno",u"all",u"alla",u"alle",u"allo",u"allora",u"altri",u"altrimenti",u"altro",u"altrove",u"altrui",u"anche",u"ancora",u"anni",u"anno",u"ansa",u"anticipo",u"assai",u"attesa",u"attraverso",u"avanti",u"avemmo",u"avendo",u"avente",u"aver",u"avere",u"averlo",u"avesse",u"avessero",u"avessi",u"avessimo",u"aveste",u"avesti",u"avete",u"aveva",u"avevamo",u"avevano",u"avevate",u"avevi",u"avevo",u"avrai",u"avranno",u"avrebbe",u"avrebbero",u"avrei",u"avremmo",u"avremo",u"avreste",u"avresti",u"avrete",u"avrà",u"avrò",u"avuta",u"avute",u"avuti",u"avuto",u"basta",u"bene",u"benissimo",u"berlusconi",u"brava",u"bravo",u"c",u"casa",u"caso",u"cento",u"certa",u"certe",u"certi",u"certo",u"che",u"chi",u"chicchessia",u"chiunque",u"ci",u"ciascuna",u"ciascuno",u"cima",u"cio",u"cioe",u"cioè",u"circa",u"citta",u"città",u"ciò",u"co",u"codesta",u"codesti",u"codesto",u"cogli",u"coi",u"col",u"colei",u"coll",u"coloro",u"colui",u"come",u"cominci",u"comunque",u"con",u"concernente",u"conciliarsi",u"conclusione",u"consiglio",u"contro",u"cortesia",u"cos",u"cosa",u"cosi",u"così",u"cui",u"d",u"da",u"dagl",u"dagli",u"dai",u"dal",u"dall",u"dalla",u"dalle",u"dallo",u"dappertutto",u"davanti",u"degl",u"degli",u"dei",u"del",u"dell",u"della",u"delle",u"dello",u"dentro",u"detto",u"deve",u"di",u"dice",u"dietro",u"dire",u"dirimpetto",u"diventa",u"diventare",u"diventato",u"dopo",u"dov",u"dove",u"dovra",u"dovrà",u"dovunque",u"due",u"dunque",u"durante",u"e",u"ebbe",u"ebbero",u"ebbi",u"ecc",u"ecco",u"ed",u"effettivamente",u"egli",u"ella",u"entrambi",u"eppure",u"era",u"erano",u"eravamo",u"eravate",u"eri",u"ero",u"esempio",u"esse",u"essendo",u"esser",u"essere",u"essi",u"ex",u"fa",u"faccia",u"facciamo",u"facciano",u"facciate",u"faccio",u"facemmo",u"facendo",u"facesse",u"facessero",u"facessi",u"facessimo",u"faceste",u"facesti",u"faceva",u"facevamo",u"facevano",u"facevate",u"facevi",u"facevo",u"fai",u"fanno",u"farai",u"faranno",u"fare",u"farebbe",u"farebbero",u"farei",u"faremmo",u"faremo",u"fareste",u"faresti",u"farete",u"farà",u"farò",u"fatto",u"favore",u"fece",u"fecero",u"feci",u"fin",u"finalmente",u"finche",u"fine",u"fino",u"forse",u"forza",u"fosse",u"fossero",u"fossi",u"fossimo",u"foste",u"fosti",u"fra",u"frattempo",u"fu",u"fui",u"fummo",u"fuori",u"furono",u"futuro",u"generale",u"gia",u"giacche",u"giorni",u"giorno",u"già",u"gli",u"gliela",u"gliele",u"glieli",u"glielo",u"gliene",u"governo",u"grande",u"grazie",u"gruppo",u"ha",u"haha",u"hai",u"hanno",u"ho",u"i",u"ieri",u"il",u"improvviso",u"in",u"inc",u"infatti",u"inoltre",u"insieme",u"intanto",u"intorno",u"invece",u"io",u"l",u"la",u"lasciato",u"lato",u"lavoro",u"le",u"lei",u"li",u"lo",u"lontano",u"loro",u"lui",u"lungo",u"luogo",u"là",u"ma",u"macche",u"magari",u"maggior",u"mai",u"male",u"malgrado",u"malissimo",u"mancanza",u"marche",u"me",u"medesimo",u"mediante",u"meglio",u"meno",u"mentre",u"mesi",u"mezzo",u"mi",u"mia",u"mie",u"miei",u"mila",u"miliardi",u"milioni",u"minimi",u"ministro",u"mio",u"modo",u"molti",u"moltissimo",u"molto",u"momento",u"mondo",u"mosto",u"nazionale",u"ne",u"negl",u"negli",u"nei",u"nel",u"nell",u"nella",u"nelle",u"nello",u"nemmeno",u"neppure",u"nessun",u"nessuna",u"nessuno",u"niente",u"no",u"noi",u"non",u"nondimeno",u"nonostante",u"nonsia",u"nostra",u"nostre",u"nostri",u"nostro",u"novanta",u"nove",u"nulla",u"nuovo",u"o",u"od",u"oggi",u"ogni",u"ognuna",u"ognuno",u"oltre",u"oppure",u"ora",u"ore",u"osi",u"ossia",u"ottanta",u"otto",u"paese",u"parecchi",u"parecchie",u"parecchio",u"parte",u"partendo",u"peccato",u"peggio",u"per",u"perche",u"perchè",u"perché",u"percio",u"perciò",u"perfino",u"pero",u"persino",u"persone",u"però",u"piedi",u"pieno",u"piglia",u"piu",u"piuttosto",u"più",u"po",u"pochissimo",u"poco",u"poi",u"poiche",u"possa",u"possedere",u"posteriore",u"posto",u"potrebbe",u"preferibilmente",u"presa",u"press",u"prima",u"primo",u"principalmente",u"probabilmente",u"proprio",u"puo",u"pure",u"purtroppo",u"può",u"qualche",u"qualcosa",u"qualcuna",u"qualcuno",u"quale",u"quali",u"qualunque",u"quando",u"quanta",u"quante",u"quanti",u"quanto",u"quantunque",u"quasi",u"quattro",u"quel",u"quella",u"quelle",u"quelli",u"quello",u"quest",u"questa",u"queste",u"questi",u"questo",u"qui",u"quindi",u"realmente",u"recente",u"recentemente",u"registrazione",u"relativo",u"riecco",u"salvo",u"sara",u"sarai",u"saranno",u"sarebbe",u"sarebbero",u"sarei",u"saremmo",u"saremo",u"sareste",u"saresti",u"sarete",u"sarà",u"sarò",u"scola",u"scopo",u"scorso",u"se",u"secondo",u"seguente",u"seguito",u"sei",u"sembra",u"sembrare",u"sembrato",u"sembri",u"sempre",u"senza",u"sette",u"si",u"sia",u"siamo",u"siano",u"siate",u"siete",u"sig",u"solito",u"solo",u"soltanto",u"sono",u"sopra",u"sotto",u"spesso",u"srl",u"sta",u"stai",u"stando",u"stanno",u"starai",u"staranno",u"starebbe",u"starebbero",u"starei",u"staremmo",u"staremo",u"stareste",u"staresti",u"starete",u"starà",u"starò",u"stata",u"state",u"stati",u"stato",u"stava",u"stavamo",u"stavano",u"stavate",u"stavi",u"stavo",u"stemmo",u"stessa",u"stesse",u"stessero",u"stessi",u"stessimo",u"stesso",u"steste",u"stesti",u"stette",u"stettero",u"stetti",u"stia",u"stiamo",u"stiano",u"stiate",u"sto",u"su",u"sua",u"subito",u"successivamente",u"successivo",u"sue",u"sugl",u"sugli",u"sui",u"sul",u"sull",u"sulla",u"sulle",u"sullo",u"suo",u"suoi",u"tale",u"tali",u"talvolta",u"tanto",u"te",u"tempo",u"ti",u"titolo",u"torino",u"tra",u"tranne",u"tre",u"trenta",u"troppo",u"trovato",u"tu",u"tua",u"tue",u"tuo",u"tuoi",u"tutta",u"tuttavia",u"tutte",u"tutti",u"tutto",u"uguali",u"ulteriore",u"ultimo",u"un",u"una",u"uno",u"uomo",u"va",u"vale",u"vari",u"varia",u"varie",u"vario",u"verso",u"vi",u"via",u"vicino",u"visto",u"vita",u"voi",u"volta",u"volte",u"vostra",u"vostre",u"vostri",u"vostro",u"è"],u"ko":[u"!",u"\"",u"$",u"%",u"&",u"'",u"(",u")",u"*",u"+",u",u",u"-",u".",u"...",u"0",u"1",u"2",u"3",u"4",u"5",u"6",u"7",u"8",u"9",u";",u"<",u"=",u">",u"?",u"@",u"\\",u"^",u"_",u"`",u"|",u"~",u"·",u"—",u"——",u"‘",u"’",u"“",u"”",u"…",u"、",u"。",u"〈",u"〉",u"《",u"》",u"가",u"가까스로",u"가령",u"각",u"각각",u"각자",u"각종",u"갖고말하자면",u"같다",u"같이",u"개의치않고",u"거니와",u"거바",u"거의",u"것",u"것과 같이",u"것들",u"게다가",u"게우다",u"겨우",u"견지에서",u"결과에 이르다",u"결국",u"결론을 낼 수 있다",u"겸사겸사",u"고려하면",u"고로",u"곧",u"공동으로",u"과",u"과연",u"관계가 있다",u"관계없이",u"관련이 있다",u"관하여",u"관한",u"관해서는",u"구",u"구체적으로",u"구토하다",u"그",u"그들",u"그때",u"그래",u"그래도",u"그래서",u"그러나",u"그러니",u"그러니까",u"그러면",u"그러므로",u"그러한즉",u"그런 까닭에",u"그런데",u"그런즉",u"그럼",u"그럼에도 불구하고",u"그렇게 함으로써",u"그렇지",u"그렇지 않다면",u"그렇지 않으면",u"그렇지만",u"그렇지않으면",u"그리고",u"그리하여",u"그만이다",u"그에 따르는",u"그위에",u"그저",u"그중에서",u"그치지 않다",u"근거로",u"근거하여",u"기대여",u"기점으로",u"기준으로",u"기타",u"까닭으로",u"까악",u"까지",u"까지 미치다",u"까지도",u"꽈당",u"끙끙",u"끼익",u"나",u"나머지는",u"남들",u"남짓",u"너",u"너희",u"너희들",u"네",u"넷",u"년",u"논하지 않다",u"놀라다",u"누가 알겠는가",u"누구",u"다른",u"다른 방면으로",u"다만",u"다섯",u"다소",u"다수",u"다시 말하자면",u"다시말하면",u"다음",u"다음에",u"다음으로",u"단지",u"답다",u"당신",u"당장",u"대로 하다",u"대하면",u"대하여",u"대해 말하자면",u"대해서",u"댕그",u"더구나",u"더군다나",u"더라도",u"더불어",u"더욱더",u"더욱이는",u"도달하다",u"도착하다",u"동시에",u"동안",u"된바에야",u"된이상",u"두번째로",u"둘",u"둥둥",u"뒤따라",u"뒤이어",u"든간에",u"들",u"등",u"등등",u"딩동",u"따라",u"따라서",u"따위",u"따지지 않다",u"딱",u"때",u"때가 되어",u"때문에",u"또",u"또한",u"뚝뚝",u"라 해도",u"령",u"로",u"로 인하여",u"로부터",u"로써",u"륙",u"를",u"마음대로",u"마저",u"마저도",u"마치",u"막론하고",u"만 못하다",u"만약",u"만약에",u"만은 아니다",u"만이 아니다",u"만일",u"만큼",u"말하자면",u"말할것도 없고",u"매",u"매번",u"메쓰겁다",u"몇",u"모",u"모두",u"무렵",u"무릎쓰고",u"무슨",u"무엇",u"무엇때문에",u"물론",u"및",u"바꾸어말하면",u"바꾸어말하자면",u"바꾸어서 말하면",u"바꾸어서 한다면",u"바꿔 말하면",u"바로",u"바와같이",u"밖에 안된다",u"반대로",u"반대로 말하자면",u"반드시",u"버금",u"보는데서",u"보다더",u"보드득",u"본대로",u"봐",u"봐라",u"부류의 사람들",u"부터",u"불구하고",u"불문하고",u"붕붕",u"비걱거리다",u"비교적",u"비길수 없다",u"비로소",u"비록",u"비슷하다",u"비추어 보아",u"비하면",u"뿐만 아니라",u"뿐만아니라",u"뿐이다",u"삐걱",u"삐걱거리다",u"사",u"삼",u"상대적으로 말하자면",u"생각한대로",u"설령",u"설마",u"설사",u"셋",u"소생",u"소인",u"솨",u"쉿",u"습니까",u"습니다",u"시각",u"시간",u"시작하여",u"시초에",u"시키다",u"실로",u"심지어",u"아",u"아니",u"아니나다를가",u"아니라면",u"아니면",u"아니었다면",u"아래윗",u"아무거나",u"아무도",u"아야",u"아울러",u"아이",u"아이고",u"아이구",u"아이야",u"아이쿠",u"아하",u"아홉",u"안 그러면",u"않기 위하여",u"않기 위해서",u"알 수 있다",u"알았어",u"앗",u"앞에서",u"앞의것",u"야",u"약간",u"양자",u"어",u"어기여차",u"어느",u"어느 년도",u"어느것",u"어느곳",u"어느때",u"어느쪽",u"어느해",u"어디",u"어때",u"어떠한",u"어떤",u"어떤것",u"어떤것들",u"어떻게",u"어떻해",u"어이",u"어째서",u"어쨋든",u"어쩔수 없다",u"어찌",u"어찌됏든",u"어찌됏어",u"어찌하든지",u"어찌하여",u"언제",u"언젠가",u"얼마",u"얼마 안 되는 것",u"얼마간",u"얼마나",u"얼마든지",u"얼마만큼",u"얼마큼",u"엉엉",u"에",u"에 가서",u"에 달려 있다",u"에 대해",u"에 있다",u"에 한하다",u"에게",u"에서",u"여",u"여기",u"여덟",u"여러분",u"여보시오",u"여부",u"여섯",u"여전히",u"여차",u"연관되다",u"연이서",u"영",u"영차",u"옆사람",u"예",u"예를 들면",u"예를 들자면",u"예컨대",u"예하면",u"오",u"오로지",u"오르다",u"오자마자",u"오직",u"오호",u"오히려",u"와",u"와 같은 사람들",u"와르르",u"와아",u"왜",u"왜냐하면",u"외에도",u"요만큼",u"요만한 것",u"요만한걸",u"요컨대",u"우르르",u"우리",u"우리들",u"우선",u"우에 종합한것과같이",u"운운",u"월",u"위에서 서술한바와같이",u"위하여",u"위해서",u"윙윙",u"육",u"으로",u"으로 인하여",u"으로서",u"으로써",u"을",u"응",u"응당",u"의",u"의거하여",u"의지하여",u"의해",u"의해되다",u"의해서",u"이",u"이 되다",u"이 때문에",u"이 밖에",u"이 외에",u"이 정도의",u"이것",u"이곳",u"이때",u"이라면",u"이래",u"이러이러하다",u"이러한",u"이런",u"이럴정도로",u"이렇게 많은 것",u"이렇게되면",u"이렇게말하자면",u"이렇구나",u"이로 인하여",u"이르기까지",u"이리하여",u"이만큼",u"이번",u"이봐",u"이상",u"이어서",u"이었다",u"이와 같다",u"이와 같은",u"이와 반대로",u"이와같다면",u"이외에도",u"이용하여",u"이유만으로",u"이젠",u"이지만",u"이쪽",u"이천구",u"이천육",u"이천칠",u"이천팔",u"인 듯하다",u"인젠",u"일",u"일것이다",u"일곱",u"일단",u"일때",u"일반적으로",u"일지라도",u"임에 틀림없다",u"입각하여",u"입장에서",u"잇따라",u"있다",u"자",u"자기",u"자기집",u"자마자",u"자신",u"잠깐",u"잠시",u"저",u"저것",u"저것만큼",u"저기",u"저쪽",u"저희",u"전부",u"전자",u"전후",u"점에서 보아",u"정도에 이르다",u"제",u"제각기",u"제외하고",u"조금",u"조차",u"조차도",u"졸졸",u"좀",u"좋아",u"좍좍",u"주룩주룩",u"주저하지 않고",u"줄은 몰랏다",u"줄은모른다",u"중에서",u"중의하나",u"즈음하여",u"즉",u"즉시",u"지든지",u"지만",u"지말고",u"진짜로",u"쪽으로",u"차라리",u"참",u"참나",u"첫번째로",u"쳇",u"총적으로",u"총적으로 말하면",u"총적으로 보면",u"칠",u"콸콸",u"쾅쾅",u"쿵",u"타다",u"타인",u"탕탕",u"토하다",u"통하여",u"툭",u"퉤",u"틈타",u"팍",u"팔",u"퍽",u"펄렁",u"하",u"하게될것이다",u"하게하다",u"하겠는가",u"하고 있다",u"하고있었다",u"하곤하였다",u"하구나",u"하기 때문에",u"하기 위하여",u"하기는한데",u"하기만 하면",u"하기보다는",u"하기에",u"하나",u"하느니",u"하는 김에",u"하는 편이 낫다",u"하는것도",u"하는것만 못하다",u"하는것이 낫다",u"하는바",u"하더라도",u"하도다",u"하도록시키다",u"하도록하다",u"하든지",u"하려고하다",u"하마터면",u"하면 할수록",u"하면된다",u"하면서",u"하물며",u"하여금",u"하여야",u"하자마자",u"하지 않는다면",u"하지 않도록",u"하지마",u"하지마라",u"하지만",u"하하",u"한 까닭에",u"한 이유는",u"한 후",u"한다면",u"한다면 몰라도",u"한데",u"한마디",u"한적이있다",u"한켠으로는",u"한항목",u"할 따름이다",u"할 생각이다",u"할 줄 안다",u"할 지경이다",u"할 힘이 있다",u"할때",u"할만하다",u"할망정",u"할뿐",u"할수있다",u"할수있어",u"할줄알다",u"할지라도",u"할지언정",u"함께",u"해도된다",u"해도좋다",u"해봐요",u"해서는 안된다",u"해야한다",u"해요",u"했어요",u"향하다",u"향하여",u"향해서",u"허",u"허걱",u"허허",u"헉",u"헉헉",u"헐떡헐떡",u"형식으로 쓰여",u"혹시",u"혹은",u"혼자",u"훨씬",u"휘익",u"휴",u"흐흐",u"흥",u"힘입어",u"︿",u"！",u"＃",u"＄",u"％",u"＆",u"（",u"）",u"＊",u"＋",u"，",u"０",u"１",u"２",u"３",u"４",u"５",u"６",u"７",u"８",u"９",u"：",u"；",u"＜",u"＞",u"？",u"＠",u"［",u"］",u"｛",u"｜",u"｝",u"～",u"￥"],u"nl":[u"aan",u"achte",u"achter",u"af",u"al",u"alle",u"alleen",u"alles",u"als",u"ander",u"anders",u"beetje",u"behalve",u"beide",u"beiden",u"ben",u"beneden",u"bent",u"bij",u"bijna",u"bijv",u"blijkbaar",u"blijken",u"boven",u"bv",u"daar",u"daardoor",u"daarin",u"daarna",u"daarom",u"daaruit",u"dan",u"dat",u"de",u"deden",u"deed",u"derde",u"derhalve",u"dertig",u"deze",u"dhr",u"die",u"dit",u"doe",u"doen",u"doet",u"door",u"drie",u"duizend",u"echter",u"een",u"eens",u"eerst",u"eerste",u"eigen",u"eigenlijk",u"elk",u"elke",u"en",u"enige",u"er",u"erg",u"ergens",u"etc",u"etcetera",u"even",u"geen",u"genoeg",u"geweest",u"haar",u"haarzelf",u"had",u"hadden",u"heb",u"hebben",u"hebt",u"hedden",u"heeft",u"heel",u"hem",u"hemzelf",u"hen",u"het",u"hetzelfde",u"hier",u"hierin",u"hierna",u"hierom",u"hij",u"hijzelf",u"hoe",u"honderd",u"hun",u"ieder",u"iedere",u"iedereen",u"iemand",u"iets",u"ik",u"in",u"inderdaad",u"intussen",u"is",u"ja",u"je",u"jij",u"jijzelf",u"jou",u"jouw",u"jullie",u"kan",u"kon",u"konden",u"kun",u"kunnen",u"kunt",u"laatst",u"later",u"lijken",u"lijkt",u"maak",u"maakt",u"maakte",u"maakten",u"maar",u"mag",u"maken",u"me",u"meer",u"meest",u"meestal",u"men",u"met",u"mevr",u"mij",u"mijn",u"minder",u"miss",u"misschien",u"missen",u"mits",u"mocht",u"mochten",u"moest",u"moesten",u"moet",u"moeten",u"mogen",u"mr",u"mrs",u"mw",u"na",u"naar",u"nam",u"namelijk",u"nee",u"neem",u"negen",u"nemen",u"nergens",u"niemand",u"niet",u"niets",u"niks",u"noch",u"nochtans",u"nog",u"nooit",u"nu",u"nv",u"of",u"om",u"omdat",u"ondanks",u"onder",u"ondertussen",u"ons",u"onze",u"onzeker",u"ooit",u"ook",u"op",u"over",u"overal",u"overige",u"paar",u"per",u"recent",u"redelijk",u"samen",u"sinds",u"steeds",u"te",u"tegen",u"tegenover",u"thans",u"tien",u"tiende",u"tijdens",u"tja",u"toch",u"toe",u"tot",u"totdat",u"tussen",u"twee",u"tweede",u"u",u"uit",u"uw",u"vaak",u"van",u"vanaf",u"veel",u"veertig",u"verder",u"verscheidene",u"verschillende",u"via",u"vier",u"vierde",u"vijf",u"vijfde",u"vijftig",u"volgend",u"volgens",u"voor",u"voordat",u"voorts",u"waar",u"waarom",u"waarschijnlijk",u"wanneer",u"waren",u"was",u"wat",u"we",u"wederom",u"weer",u"weinig",u"wel",u"welk",u"welke",u"werd",u"werden",u"werder",u"whatever",u"wie",u"wij",u"wijzelf",u"wil",u"wilden",u"willen",u"word",u"worden",u"wordt",u"zal",u"ze",u"zei",u"zeker",u"zelf",u"zelfde",u"zes",u"zeven",u"zich",u"zij",u"zijn",u"zijzelf",u"zo",u"zoals",u"zodat",u"zou",u"zouden",u"zulk",u"zullen"],u"no":[u"alle",u"at",u"av",u"bare",u"begge",u"ble",u"blei",u"bli",u"blir",u"blitt",u"både",u"båe",u"da",u"de",u"deg",u"dei",u"deim",u"deira",u"deires",u"dem",u"den",u"denne",u"der",u"dere",u"deres",u"det",u"dette",u"di",u"din",u"disse",u"ditt",u"du",u"dykk",u"dykkar",u"då",u"eg",u"ein",u"eit",u"eitt",u"eller",u"elles",u"en",u"enn",u"er",u"et",u"ett",u"etter",u"for",u"fordi",u"fra",u"før",u"ha",u"hadde",u"han",u"hans",u"har",u"hennar",u"henne",u"hennes",u"her",u"hjå",u"ho",u"hoe",u"honom",u"hoss",u"hossen",u"hun",u"hva",u"hvem",u"hver",u"hvilke",u"hvilken",u"hvis",u"hvor",u"hvordan",u"hvorfor",u"i",u"ikke",u"ikkje",u"ingen",u"ingi",u"inkje",u"inn",u"inni",u"ja",u"jeg",u"kan",u"kom",u"korleis",u"korso",u"kun",u"kunne",u"kva",u"kvar",u"kvarhelst",u"kven",u"kvi",u"kvifor",u"man",u"mange",u"me",u"med",u"medan",u"meg",u"meget",u"mellom",u"men",u"mi",u"min",u"mine",u"mitt",u"mot",u"mykje",u"ned",u"no",u"noe",u"noen",u"noka",u"noko",u"nokon",u"nokor",u"nokre",u"nå",u"når",u"og",u"også",u"om",u"opp",u"oss",u"over",u"på",u"samme",u"seg",u"selv",u"si",u"sia",u"sidan",u"siden",u"sin",u"sine",u"sitt",u"sjøl",u"skal",u"skulle",u"slik",u"so",u"som",u"somme",u"somt",u"så",u"sånn",u"til",u"um",u"upp",u"ut",u"uten",u"var",u"vart",u"varte",u"ved",u"vere",u"verte",u"vi",u"vil",u"ville",u"vore",u"vors",u"vort",u"vår",u"være",u"vært",u"å"],u"pl":[u"aby",u"ach",u"aj",u"albo",u"ale",u"ani",u"aż",u"bardzo",u"bez",u"bo",u"bowiem",u"by",u"byli",u"bym",u"być",u"był",u"była",u"było",u"były",u"będzie",u"będą",u"chce",u"choć",u"ci",u"ciebie",u"cię",u"co",u"coraz",u"coś",u"czy",u"czyli",u"często",u"daleko",u"dla",u"dlaczego",u"dlatego",u"do",u"dobrze",u"dokąd",u"dość",u"dr",u"dużo",u"dwa",u"dwaj",u"dwie",u"dwoje",u"dzisiaj",u"dziś",u"gdy",u"gdyby",u"gdyż",u"gdzie",u"go",u"godz",u"hab",u"i",u"ich",u"ii",u"iii",u"ile",u"im",u"inne",u"inny",u"inż",u"iv",u"ix",u"iż",u"ja",u"jak",u"jakby",u"jaki",u"jakie",u"jako",u"je",u"jeden",u"jedna",u"jednak",u"jedno",u"jednym",u"jedynie",u"jego",u"jej",u"jemu",u"jest",u"jestem",u"jeszcze",u"jeśli",u"jeżeli",u"już",u"ją",u"każdy",u"kiedy",u"kierunku",u"kilku",u"kto",u"która",u"które",u"którego",u"której",u"który",u"których",u"którym",u"którzy",u"ku",u"lat",u"lecz",u"lub",u"ma",u"mają",u"mam",u"mamy",u"mgr",u"mi",u"miał",u"mimo",u"mnie",u"mną",u"mogą",u"moi",u"moja",u"moje",u"może",u"można",u"mu",u"musi",u"my",u"mój",u"na",u"nad",u"nam",u"nami",u"nas",u"nasi",u"nasz",u"nasza",u"nasze",u"natychmiast",u"nawet",u"nic",u"nich",u"nie",u"niego",u"niej",u"niemu",u"nigdy",u"nim",u"nimi",u"nią",u"niż",u"no",u"nowe",u"np",u"nr",u"o",u"o.o.",u"obok",u"od",u"ok",u"około",u"on",u"ona",u"one",u"oni",u"ono",u"oraz",u"owszem",u"pan",u"pl",u"po",u"pod",u"ponad",u"ponieważ",u"poza",u"prof",u"przed",u"przede",u"przedtem",u"przez",u"przy",u"raz",u"razie",u"roku",u"również",u"sam",u"sama",u"się",u"skąd",u"sobie",u"sposób",u"swoje",u"są",u"ta",u"tak",u"taki",u"takich",u"takie",u"także",u"tam",u"te",u"tego",u"tej",u"tel",u"temu",u"ten",u"teraz",u"też",u"to",u"tobie",u"tobą",u"trzeba",u"tu",u"tutaj",u"twoi",u"twoja",u"twoje",u"twój",u"ty",u"tych",u"tylko",u"tym",u"tys",u"tzw",u"tę",u"u",u"ul",u"vi",u"vii",u"viii",u"vol",u"w",u"wam",u"wami",u"was",u"wasi",u"wasz",u"wasza",u"wasze",u"we",u"wie",u"więc",u"wszystko",u"wtedy",u"www",u"wy",u"właśnie",u"wśród",u"xi",u"xii",u"xiii",u"xiv",u"xv",u"z",u"za",u"zawsze",u"zaś",u"ze",u"zł",u"żaden",u"że",u"żeby"],u"pt":[u"a",u"acerca",u"adeus",u"agora",u"ainda",u"algmas",u"algo",u"algumas",u"alguns",u"ali",u"além",u"ambos",u"ano",u"anos",u"antes",u"ao",u"aos",u"apenas",u"apoio",u"apontar",u"após",u"aquela",u"aquelas",u"aquele",u"aqueles",u"aqui",u"aquilo",u"as",u"assim",u"através",u"atrás",u"até",u"aí",u"baixo",u"bastante",u"bem",u"bom",u"breve",u"cada",u"caminho",u"catorze",u"cedo",u"cento",u"certamente",u"certeza",u"cima",u"cinco",u"coisa",u"com",u"como",u"comprido",u"conhecido",u"conselho",u"contra",u"corrente",u"custa",u"cá",u"da",u"daquela",u"daquele",u"dar",u"das",u"de",u"debaixo",u"demais",u"dentro",u"depois",u"desde",u"desligado",u"dessa",u"desse",u"desta",u"deste",u"deve",u"devem",u"deverá",u"dez",u"dezanove",u"dezasseis",u"dezassete",u"dezoito",u"dia",u"diante",u"direita",u"diz",u"dizem",u"dizer",u"do",u"dois",u"dos",u"doze",u"duas",u"dá",u"dão",u"dúvida",u"e",u"ela",u"elas",u"ele",u"eles",u"em",u"embora",u"enquanto",u"entre",u"então",u"era",u"essa",u"essas",u"esse",u"esses",u"esta",u"estado",u"estar",u"estará",u"estas",u"estava",u"este",u"estes",u"esteve",u"estive",u"estivemos",u"estiveram",u"estiveste",u"estivestes",u"estou",u"está",u"estás",u"estão",u"eu",u"exemplo",u"falta",u"fará",u"favor",u"faz",u"fazeis",u"fazem",u"fazemos",u"fazer",u"fazes",u"fazia",u"faço",u"fez",u"fim",u"final",u"foi",u"fomos",u"for",u"fora",u"foram",u"forma",u"foste",u"fostes",u"fui",u"geral",u"grande",u"grandes",u"grupo",u"hoje",u"horas",u"há",u"iniciar",u"inicio",u"ir",u"irá",u"isso",u"ista",u"iste",u"isto",u"já",u"lado",u"ligado",u"local",u"logo",u"longe",u"lugar",u"lá",u"maior",u"maioria",u"maiorias",u"mais",u"mal",u"mas",u"me",u"meio",u"menor",u"menos",u"meses",u"mesmo",u"meu",u"meus",u"mil",u"minha",u"minhas",u"momento",u"muito",u"muitos",u"máximo",u"mês",u"na",u"nada",u"naquela",u"naquele",u"nas",u"nem",u"nenhuma",u"nessa",u"nesse",u"nesta",u"neste",u"no",u"noite",u"nome",u"nos",u"nossa",u"nossas",u"nosso",u"nossos",u"nova",u"nove",u"novo",u"novos",u"num",u"numa",u"nunca",u"não",u"nível",u"nós",u"número",u"o",u"obra",u"obrigada",u"obrigado",u"oitava",u"oitavo",u"oito",u"onde",u"ontem",u"onze",u"os",u"ou",u"outra",u"outras",u"outro",u"outros",u"para",u"parece",u"parte",u"partir",u"pegar",u"pela",u"pelas",u"pelo",u"pelos",u"perto",u"pessoas",u"pode",u"podem",u"poder",u"poderá",u"podia",u"ponto",u"pontos",u"por",u"porque",u"porquê",u"posição",u"possivelmente",u"posso",u"possível",u"pouca",u"pouco",u"povo",u"primeira",u"primeiro",u"promeiro",u"próprio",u"próximo",u"puderam",u"pôde",u"põe",u"põem",u"qual",u"qualquer",u"quando",u"quanto",u"quarta",u"quarto",u"quatro",u"que",u"quem",u"quer",u"quero",u"questão",u"quieto",u"quinta",u"quinto",u"quinze",u"quê",u"relação",u"sabe",u"saber",u"se",u"segunda",u"segundo",u"sei",u"seis",u"sem",u"sempre",u"ser",u"seria",u"sete",u"seu",u"seus",u"sexta",u"sexto",u"sim",u"sistema",u"sob",u"sobre",u"sois",u"somente",u"somos",u"sou",u"sua",u"suas",u"são",u"sétima",u"sétimo",u"tal",u"talvez",u"também",u"tanto",u"tarde",u"te",u"tem",u"temos",u"tempo",u"tendes",u"tenho",u"tens",u"tentar",u"tentaram",u"tente",u"tentei",u"ter",u"terceira",u"terceiro",u"teu",u"teus",u"teve",u"tipo",u"tive",u"tivemos",u"tiveram",u"tiveste",u"tivestes",u"toda",u"todas",u"todo",u"todos",u"trabalhar",u"trabalho",u"treze",u"três",u"tu",u"tua",u"tuas",u"tudo",u"tão",u"têm",u"um",u"uma",u"umas",u"uns",u"usa",u"usar",u"vai",u"vais",u"valor",u"veja",u"vem",u"vens",u"ver",u"verdade",u"verdadeiro",u"vez",u"vezes",u"viagem",u"vindo",u"vinte",u"você",u"vocês",u"vos",u"vossa",u"vossas",u"vosso",u"vossos",u"vários",u"vão",u"vêm",u"vós",u"zero",u"à",u"às",u"área",u"é",u"és",u"último"],u"ru":[u"а",u"алло",u"без",u"белый",u"близко",u"более",u"больше",u"большой",u"будем",u"будет",u"будете",u"будешь",u"будто",u"буду",u"будут",u"будь",u"бы",u"бывает",u"бывь",u"был",u"была",u"были",u"было",u"быть",u"в",u"важная",u"важное",u"важные",u"важный",u"вам",u"вами",u"вас",u"ваш",u"ваша",u"ваше",u"ваши",u"вверх",u"вдали",u"вдруг",u"ведь",u"везде",u"вернуться",u"весь",u"вечер",u"взгляд",u"взять",u"вид",u"видеть",u"вместе",u"вниз",u"внизу",u"во",u"вода",u"война",u"вокруг",u"вон",u"вообще",u"вопрос",u"восемнадцатый",u"восемнадцать",u"восемь",u"восьмой",u"вот",u"впрочем",u"времени",u"время",u"все",u"всегда",u"всего",u"всем",u"всеми",u"всему",u"всех",u"всею",u"всю",u"всюду",u"вся",u"всё",u"второй",u"вы",u"выйти",u"г",u"где",u"главный",u"глаз",u"говорил",u"говорит",u"говорить",u"год",u"года",u"году",u"голова",u"голос",u"город",u"да",u"давать",u"давно",u"даже",u"далекий",u"далеко",u"дальше",u"даром",u"дать",u"два",u"двадцатый",u"двадцать",u"две",u"двенадцатый",u"двенадцать",u"дверь",u"двух",u"девятнадцатый",u"девятнадцать",u"девятый",u"девять",u"действительно",u"дел",u"делать",u"дело",u"день",u"деньги",u"десятый",u"десять",u"для",u"до",u"довольно",u"долго",u"должно",u"должный",u"дом",u"дорога",u"друг",u"другая",u"другие",u"других",u"друго",u"другое",u"другой",u"думать",u"душа",u"е",u"его",u"ее",u"ей",u"ему",u"если",u"есть",u"еще",u"ещё",u"ею",u"её",u"ж",u"ждать",u"же",u"жена",u"женщина",u"жизнь",u"жить",u"за",u"занят",u"занята",u"занято",u"заняты",u"затем",u"зато",u"зачем",u"здесь",u"земля",u"знать",u"значит",u"значить",u"и",u"идти",u"из",u"или",u"им",u"именно",u"иметь",u"ими",u"имя",u"иногда",u"их",u"к",u"каждая",u"каждое",u"каждые",u"каждый",u"кажется",u"казаться",u"как",u"какая",u"какой",u"кем",u"книга",u"когда",u"кого",u"ком",u"комната",u"кому",u"конец",u"конечно",u"которая",u"которого",u"которой",u"которые",u"который",u"которых",u"кроме",u"кругом",u"кто",u"куда",u"лежать",u"лет",u"ли",u"лицо",u"лишь",u"лучше",u"любить",u"люди",u"м",u"маленький",u"мало",u"мать",u"машина",u"между",u"меля",u"менее",u"меньше",u"меня",u"место",u"миллионов",u"мимо",u"минута",u"мир",u"мира",u"мне",u"много",u"многочисленная",u"многочисленное",u"многочисленные",u"многочисленный",u"мной",u"мною",u"мог",u"могут",u"мож",u"может",u"можно",u"можхо",u"мои",u"мой",u"мор",u"москва",u"мочь",u"моя",u"моё",u"мы",u"на",u"наверху",u"над",u"надо",u"назад",u"наиболее",u"найти",u"наконец",u"нам",u"нами",u"народ",u"нас",u"начала",u"начать",u"наш",u"наша",u"наше",u"наши",u"не",u"него",u"недавно",u"недалеко",u"нее",u"ней",u"некоторый",u"нельзя",u"нем",u"немного",u"нему",u"непрерывно",u"нередко",u"несколько",u"нет",u"нею",u"неё",u"ни",u"нибудь",u"ниже",u"низко",u"никакой",u"никогда",u"никто",u"никуда",u"ними",u"них",u"ничего",u"ничто",u"но",u"новый",u"нога",u"ночь",u"ну",u"нужно",u"нужный",u"нх",u"о",u"об",u"оба",u"обычно",u"один",u"одиннадцатый",u"одиннадцать",u"однажды",u"однако",u"одного",u"одной",u"оказаться",u"окно",u"около",u"он",u"она",u"они",u"оно",u"опять",u"особенно",u"остаться",u"от",u"ответить",u"отец",u"отовсюду",u"отсюда",u"очень",u"первый",u"перед",u"писать",u"плечо",u"по",u"под",u"подумать",u"пожалуйста",u"позже",u"пойти",u"пока",u"пол",u"получить",u"помнить",u"понимать",u"понять",u"пор",u"пора",u"после",u"последний",u"посмотреть",u"посреди",u"потом",u"потому",u"почему",u"почти",u"правда",u"прекрасно",u"при",u"про",u"просто",u"против",u"процентов",u"пятнадцатый",u"пятнадцать",u"пятый",u"пять",u"работа",u"работать",u"раз",u"разве",u"рано",u"раньше",u"ребенок",u"решить",u"россия",u"рука",u"русский",u"ряд",u"рядом",u"с",u"сам",u"сама",u"сами",u"самим",u"самими",u"самих",u"само",u"самого",u"самой",u"самом",u"самому",u"саму",u"самый",u"свет",u"свое",u"своего",u"своей",u"свои",u"своих",u"свой",u"свою",u"сделать",u"сеаой",u"себе",u"себя",u"сегодня",u"седьмой",u"сейчас",u"семнадцатый",u"семнадцать",u"семь",u"сидеть",u"сила",u"сих",u"сказал",u"сказала",u"сказать",u"сколько",u"слишком",u"слово",u"случай",u"смотреть",u"сначала",u"снова",u"со",u"собой",u"собою",u"советский",u"совсем",u"спасибо",u"спросить",u"сразу",u"стал",u"старый",u"стать",u"стол",u"сторона",u"стоять",u"страна",u"суть",u"считать",u"т",u"та",u"так",u"такая",u"также",u"таки",u"такие",u"такое",u"такой",u"там",u"твой",u"твоя",u"твоё",u"те",u"тебе",u"тебя",u"тем",u"теми",u"теперь",u"тех",u"то",u"тобой",u"тобою",u"товарищ",u"тогда",u"того",u"тоже",u"только",u"том",u"тому",u"тот",u"тою",u"третий",u"три",u"тринадцатый",u"тринадцать",u"ту",u"туда",u"тут",u"ты",u"тысяч",u"у",u"увидеть",u"уж",u"уже",u"улица",u"уметь",u"утро",u"хороший",u"хорошо",u"хотеть",u"хоть",u"хотя",u"хочешь",u"час",u"часто",u"часть",u"чаще",u"чего",u"человек",u"чем",u"чему",u"через",u"четвертый",u"четыре",u"четырнадцатый",u"четырнадцать",u"что",u"чтоб",u"чтобы",u"чуть",u"шестнадцатый",u"шестнадцать",u"шестой",u"шесть",u"эта",u"эти",u"этим",u"этими",u"этих",u"это",u"этого",u"этой",u"этом",u"этому",u"этот",u"эту",u"я"],u"sv":[u"aderton",u"adertonde",u"adjö",u"aldrig",u"alla",u"allas",u"allt",u"alltid",u"alltså",u"andra",u"andras",u"annan",u"annat",u"artonde",u"artonn",u"att",u"av",u"bakom",u"bara",u"behöva",u"behövas",u"behövde",u"behövt",u"beslut",u"beslutat",u"beslutit",u"bland",u"blev",u"bli",u"blir",u"blivit",u"bort",u"borta",u"bra",u"bäst",u"bättre",u"båda",u"bådas",u"dag",u"dagar",u"dagarna",u"dagen",u"de",u"del",u"delen",u"dem",u"den",u"denna",u"deras",u"dess",u"dessa",u"det",u"detta",u"dig",u"din",u"dina",u"dit",u"ditt",u"dock",u"du",u"där",u"därför",u"då",u"efter",u"eftersom",u"ej",u"elfte",u"eller",u"elva",u"en",u"enkel",u"enkelt",u"enkla",u"enligt",u"er",u"era",u"ert",u"ett",u"ettusen",u"fanns",u"fem",u"femte",u"femtio",u"femtionde",u"femton",u"femtonde",u"fick",u"fin",u"finnas",u"finns",u"fjorton",u"fjortonde",u"fjärde",u"fler",u"flera",u"flesta",u"fram",u"framför",u"från",u"fyra",u"fyrtio",u"fyrtionde",u"få",u"får",u"fått",u"följande",u"för",u"före",u"förlåt",u"förra",u"första",u"genast",u"genom",u"gick",u"gjorde",u"gjort",u"god",u"goda",u"godare",u"godast",u"gott",u"gälla",u"gäller",u"gällt",u"gärna",u"gå",u"går",u"gått",u"gör",u"göra",u"ha",u"hade",u"haft",u"han",u"hans",u"har",u"heller",u"hellre",u"helst",u"helt",u"henne",u"hennes",u"hit",u"hon",u"honom",u"hundra",u"hundraen",u"hundraett",u"hur",u"här",u"hög",u"höger",u"högre",u"högst",u"i",u"ibland",u"icke",u"idag",u"igen",u"igår",u"imorgon",u"in",u"inför",u"inga",u"ingen",u"ingenting",u"inget",u"innan",u"inne",u"inom",u"inte",u"inuti",u"ja",u"jag",u"ju",u"jämfört",u"kan",u"kanske",u"knappast",u"kom",u"komma",u"kommer",u"kommit",u"kr",u"kunde",u"kunna",u"kunnat",u"kvar",u"legat",u"ligga",u"ligger",u"lika",u"likställd",u"likställda",u"lilla",u"lite",u"liten",u"litet",u"länge",u"längre",u"längst",u"lätt",u"lättare",u"lättast",u"långsam",u"långsammare",u"långsammast",u"långsamt",u"långt",u"man",u"med",u"mellan",u"men",u"mer",u"mera",u"mest",u"mig",u"min",u"mina",u"mindre",u"minst",u"mitt",u"mittemot",u"mot",u"mycket",u"många",u"måste",u"möjlig",u"möjligen",u"möjligt",u"möjligtvis",u"ned",u"nederst",u"nedersta",u"nedre",u"nej",u"ner",u"ni",u"nio",u"nionde",u"nittio",u"nittionde",u"nitton",u"nittonde",u"nog",u"noll",u"nr",u"nu",u"nummer",u"när",u"nästa",u"någon",u"någonting",u"något",u"några",u"nödvändig",u"nödvändiga",u"nödvändigt",u"nödvändigtvis",u"och",u"också",u"ofta",u"oftast",u"olika",u"olikt",u"om",u"oss",u"på",u"rakt",u"redan",u"rätt",u"sade",u"sagt",u"samma",u"sedan",u"senare",u"senast",u"sent",u"sex",u"sextio",u"sextionde",u"sexton",u"sextonde",u"sig",u"sin",u"sina",u"sist",u"sista",u"siste",u"sitt",u"sitta",u"sju",u"sjunde",u"sjuttio",u"sjuttionde",u"sjutton",u"sjuttonde",u"själv",u"sjätte",u"ska",u"skall",u"skulle",u"slutligen",u"små",u"smått",u"snart",u"som",u"stor",u"stora",u"stort",u"större",u"störst",u"säga",u"säger",u"sämre",u"sämst",u"så",u"sådan",u"sådana",u"sådant",u"tack",u"tidig",u"tidigare",u"tidigast",u"tidigt",u"till",u"tills",u"tillsammans",u"tio",u"tionde",u"tjugo",u"tjugoen",u"tjugoett",u"tjugonde",u"tjugotre",u"tjugotvå",u"tjungo",u"tolfte",u"tolv",u"tre",u"tredje",u"trettio",u"trettionde",u"tretton",u"trettonde",u"två",u"tvåhundra",u"under",u"upp",u"ur",u"ursäkt",u"ut",u"utan",u"utanför",u"ute",u"vad",u"var",u"vara",u"varför",u"varifrån",u"varit",u"varje",u"varken",u"vars",u"varsågod",u"vart",u"vem",u"vems",u"verkligen",u"vi",u"vid",u"vidare",u"viktig",u"viktigare",u"viktigast",u"viktigt",u"vilka",u"vilkas",u"vilken",u"vilket",u"vill",u"vänster",u"vänstra",u"värre",u"vår",u"våra",u"vårt",u"än",u"ännu",u"är",u"även",u"åt",u"åtminstone",u"åtta",u"åttio",u"åttionde",u"åttonde",u"över",u"övermorgon",u"överst",u"övre"],u"tr":[u"acaba",u"acep",u"adeta",u"altmýþ",u"altmış",u"altý",u"altı",u"ama",u"ancak",u"arada",u"artýk",u"aslında",u"aynen",u"ayrıca",u"az",u"bana",u"bari",u"bazen",u"bazý",u"bazı",u"baţka",u"belki",u"ben",u"benden",u"beni",u"benim",u"beri",u"beþ",u"beş",u"beţ",u"bile",u"bin",u"bir",u"biraz",u"biri",u"birkaç",u"birkez",u"birçok",u"birþey",u"birþeyi",u"birşey",u"birşeyi",u"birţey",u"biz",u"bizden",u"bize",u"bizi",u"bizim",u"bu",u"buna",u"bunda",u"bundan",u"bunlar",u"bunları",u"bunların",u"bunu",u"bunun",u"burada",u"böyle",u"böylece",u"bütün",u"da",u"daha",u"dahi",u"dahil",u"daima",u"dair",u"dayanarak",u"de",u"defa",u"deđil",u"değil",u"diye",u"diđer",u"diğer",u"doksan",u"dokuz",u"dolayı",u"dolayısıyla",u"dört",u"edecek",u"eden",u"ederek",u"edilecek",u"ediliyor",u"edilmesi",u"ediyor",u"elli",u"en",u"etmesi",u"etti",u"ettiği",u"ettiğini",u"eđer",u"eğer",u"fakat",u"gibi",u"göre",u"halbuki",u"halen",u"hangi",u"hani",u"hariç",u"hatta",u"hele",u"hem",u"henüz",u"hep",u"hepsi",u"her",u"herhangi",u"herkes",u"herkesin",u"hiç",u"hiçbir",u"iken",u"iki",u"ila",u"ile",u"ilgili",u"ilk",u"illa",u"ise",u"itibaren",u"itibariyle",u"iyi",u"iyice",u"için",u"işte",u"iţte",u"kadar",u"kanýmca",u"karşın",u"katrilyon",u"kendi",u"kendilerine",u"kendini",u"kendisi",u"kendisine",u"kendisini",u"kere",u"kez",u"keţke",u"ki",u"kim",u"kimden",u"kime",u"kimi",u"kimse",u"kýrk",u"kýsaca",u"kırk",u"lakin",u"madem",u"međer",u"milyar",u"milyon",u"mu",u"mü",u"mý",u"mı",u"nasýl",u"nasıl",u"ne",u"neden",u"nedenle",u"nerde",u"nere",u"nerede",u"nereye",u"nitekim",u"niye",u"niçin",u"o",u"olan",u"olarak",u"oldu",u"olduklarını",u"olduğu",u"olduğunu",u"olmadı",u"olmadığı",u"olmak",u"olması",u"olmayan",u"olmaz",u"olsa",u"olsun",u"olup",u"olur",u"olursa",u"oluyor",u"on",u"ona",u"ondan",u"onlar",u"onlardan",u"onlari",u"onlarýn",u"onları",u"onların",u"onu",u"onun",u"otuz",u"oysa",u"pek",u"rağmen",u"sadece",u"sanki",u"sekiz",u"seksen",u"sen",u"senden",u"seni",u"senin",u"siz",u"sizden",u"sizi",u"sizin",u"sonra",u"tarafından",u"trilyon",u"tüm",u"var",u"vardı",u"ve",u"veya",u"veyahut",u"ya",u"yahut",u"yani",u"yapacak",u"yapmak",u"yaptı",u"yaptıkları",u"yaptığı",u"yaptığını",u"yapılan",u"yapılması",u"yapıyor",u"yedi",u"yerine",u"yetmiþ",u"yetmiş",u"yetmiţ",u"yine",u"yirmi",u"yoksa",u"yüz",u"zaten",u"çok",u"çünkü",u"öyle",u"üzere",u"üç",u"þey",u"þeyden",u"þeyi",u"þeyler",u"þu",u"þuna",u"þunda",u"þundan",u"þunu",u"şey",u"şeyden",u"şeyi",u"şeyler",u"şu",u"şuna",u"şunda",u"şundan",u"şunları",u"şunu",u"şöyle",u"ţayet",u"ţimdi",u"ţu",u"ţöyle"],u"zh":[u"、",u"。",u"〈",u"〉",u"《",u"》",u"一",u"一切",u"一则",u"一方面",u"一旦",u"一来",u"一样",u"一般",u"七",u"万一",u"三",u"上下",u"不仅",u"不但",u"不光",u"不单",u"不只",u"不如",u"不怕",u"不惟",u"不成",u"不拘",u"不比",u"不然",u"不特",u"不独",u"不管",u"不论",u"不过",u"不问",u"与",u"与其",u"与否",u"与此同时",u"且",u"两者",u"个",u"临",u"为",u"为了",u"为什么",u"为何",u"为着",u"乃",u"乃至",u"么",u"之",u"之一",u"之所以",u"之类",u"乌乎",u"乎",u"乘",u"九",u"也",u"也好",u"也罢",u"了",u"二",u"于",u"于是",u"于是乎",u"云云",u"五",u"人家",u"什么",u"什么样",u"从",u"从而",u"他",u"他人",u"他们",u"以",u"以便",u"以免",u"以及",u"以至",u"以至于",u"以致",u"们",u"任",u"任何",u"任凭",u"似的",u"但",u"但是",u"何",u"何况",u"何处",u"何时",u"作为",u"你",u"你们",u"使得",u"例如",u"依",u"依照",u"俺",u"俺们",u"倘",u"倘使",u"倘或",u"倘然",u"倘若",u"借",u"假使",u"假如",u"假若",u"像",u"八",u"六",u"兮",u"关于",u"其",u"其一",u"其中",u"其二",u"其他",u"其余",u"其它",u"其次",u"具体地说",u"具体说来",u"再者",u"再说",u"冒",u"冲",u"况且",u"几",u"几时",u"凭",u"凭借",u"则",u"别",u"别的",u"别说",u"到",u"前后",u"前者",u"加之",u"即",u"即令",u"即使",u"即便",u"即或",u"即若",u"又",u"及",u"及其",u"及至",u"反之",u"反过来",u"反过来说",u"另",u"另一方面",u"另外",u"只是",u"只有",u"只要",u"只限",u"叫",u"叮咚",u"可",u"可以",u"可是",u"可见",u"各",u"各个",u"各位",u"各种",u"各自",u"同",u"同时",u"向",u"向着",u"吓",u"吗",u"否则",u"吧",u"吧哒",u"吱",u"呀",u"呃",u"呕",u"呗",u"呜",u"呜呼",u"呢",u"呵",u"呸",u"呼哧",u"咋",u"和",u"咚",u"咦",u"咱",u"咱们",u"咳",u"哇",u"哈",u"哈哈",u"哉",u"哎",u"哎呀",u"哎哟",u"哗",u"哟",u"哦",u"哩",u"哪",u"哪个",u"哪些",u"哪儿",u"哪天",u"哪年",u"哪怕",u"哪样",u"哪边",u"哪里",u"哼",u"哼唷",u"唉",u"啊",u"啐",u"啥",u"啦",u"啪达",u"喂",u"喏",u"喔唷",u"嗡嗡",u"嗬",u"嗯",u"嗳",u"嘎",u"嘎登",u"嘘",u"嘛",u"嘻",u"嘿",u"四",u"因",u"因为",u"因此",u"因而",u"固然",u"在",u"在下",u"地",u"多",u"多少",u"她",u"她们",u"如",u"如上所述",u"如何",u"如其",u"如果",u"如此",u"如若",u"宁",u"宁可",u"宁愿",u"宁肯",u"它",u"它们",u"对",u"对于",u"将",u"尔后",u"尚且",u"就",u"就是",u"就是说",u"尽",u"尽管",u"岂但",u"己",u"并",u"并且",u"开外",u"开始",u"归",u"当",u"当着",u"彼",u"彼此",u"往",u"待",u"得",u"怎",u"怎么",u"怎么办",u"怎么样",u"怎样",u"总之",u"总的来看",u"总的来说",u"总的说来",u"总而言之",u"恰恰相反",u"您",u"慢说",u"我",u"我们",u"或",u"或是",u"或者",u"所",u"所以",u"打",u"把",u"抑或",u"拿",u"按",u"按照",u"换句话说",u"换言之",u"据",u"接着",u"故",u"故此",u"旁人",u"无宁",u"无论",u"既",u"既是",u"既然",u"时候",u"是",u"是的",u"替",u"有",u"有些",u"有关",u"有的",u"望",u"朝",u"朝着",u"本",u"本着",u"来",u"来着",u"极了",u"果然",u"果真",u"某",u"某个",u"某些",u"根据",u"正如",u"此",u"此外",u"此间",u"毋宁",u"每",u"每当",u"比",u"比如",u"比方",u"沿",u"沿着",u"漫说",u"焉",u"然则",u"然后",u"然而",u"照",u"照着",u"甚么",u"甚而",u"甚至",u"用",u"由",u"由于",u"由此可见",u"的",u"的话",u"相对而言",u"省得",u"着",u"着呢",u"矣",u"离",u"第",u"等",u"等等",u"管",u"紧接着",u"纵",u"纵令",u"纵使",u"纵然",u"经",u"经过",u"结果",u"给",u"继而",u"综上所述",u"罢了",u"者",u"而",u"而且",u"而况",u"而外",u"而已",u"而是",u"而言",u"能",u"腾",u"自",u"自个儿",u"自从",u"自各儿",u"自家",u"自己",u"自身",u"至",u"至于",u"若",u"若是",u"若非",u"莫若",u"虽",u"虽则",u"虽然",u"虽说",u"被",u"要",u"要不",u"要不是",u"要不然",u"要么",u"要是",u"让",u"论",u"设使",u"设若",u"该",u"诸位",u"谁",u"谁知",u"赶",u"起",u"起见",u"趁",u"趁着",u"越是",u"跟",u"较",u"较之",u"边",u"过",u"还是",u"还有",u"这",u"这个",u"这么",u"这么些",u"这么样",u"这么点儿",u"这些",u"这会儿",u"这儿",u"这就是说",u"这时",u"这样",u"这边",u"这里",u"进而",u"连",u"连同",u"通过",u"遵照",u"那",u"那个",u"那么",u"那么些",u"那么样",u"那些",u"那会儿",u"那儿",u"那时",u"那样",u"那边",u"那里",u"鄙人",u"鉴于",u"阿",u"除",u"除了",u"除此之外",u"除非",u"随",u"随着",u"零",u"非但",u"非徒",u"靠",u"顺",u"顺着",u"首先",u"︿",u"！",u"＃",u"＄",u"％",u"＆",u"（",u"）",u"＊",u"＋",u"，",u"０",u"１",u"２",u"３",u"４",u"５",u"６",u"７",u"８",u"９",u"：",u"；",u"＜",u"＞",u"？",u"＠",u"［",u"］",u"｛",u"｜",u"｝",u"～",u"￥"],u"eo":[u"adiaŭ",u"ajn",u"al",u"ankoraŭ",u"antaŭ",u"aŭ",u"bonan",u"bonvole",u"bonvolu",u"bv",u"ci",u"cia",u"cian",u"cin",u"d-ro",u"da",u"de",u"dek",u"deka",u"do",u"doktor'",u"doktoro",u"du",u"dua",u"dum",u"eble",u"ekz",u"ekzemple",u"en",u"estas",u"estis",u"estos",u"estu",u"estus",u"eĉ",u"f-no",u"feliĉan",u"for",u"fraŭlino",u"ha",u"havas",u"havis",u"havos",u"havu",u"havus",u"he",u"ho",u"hu",u"ili",u"ilia",u"ilian",u"ilin",u"inter",u"io",u"ion",u"iu",u"iujn",u"iun",u"ja",u"jam",u"je",u"jes",u"k",u"kaj",u"ke",u"kio",u"kion",u"kiu",u"kiujn",u"kiun",u"kvankam",u"kvar",u"kvara",u"kvazaŭ",u"kvin",u"kvina",u"la",u"li",u"lia",u"lian",u"lin",u"malantaŭ",u"male",u"malgraŭ",u"mem",u"mi",u"mia",u"mian",u"min",u"minus",u"naŭ",u"naŭa",u"ne",u"nek",u"nenio",u"nenion",u"neniu",u"neniun",u"nepre",u"ni",u"nia",u"nian",u"nin",u"nu",u"nun",u"nur",u"ok",u"oka",u"oni",u"onia",u"onian",u"onin",u"plej",u"pli",u"plu",u"plus",u"por",u"post",u"preter",u"s-no",u"s-ro",u"se",u"sed",u"sep",u"sepa",u"ses",u"sesa",u"si",u"sia",u"sian",u"sin",u"sinjor'",u"sinjorino",u"sinjoro",u"sub",u"super",u"supren",u"sur",u"tamen",u"tio",u"tion",u"tiu",u"tiujn",u"tiun",u"tra",u"tri",u"tria",u"tuj",u"tute",u"unu",u"unua",u"ve",u"verŝajne",u"vi",u"via",u"vian",u"vin",u"ĉi",u"ĉio",u"ĉion",u"ĉiu",u"ĉiujn",u"ĉiun",u"ĉu",u"ĝi",u"ĝia",u"ĝian",u"ĝin",u"ĝis",u"ĵus",u"ŝi",u"ŝia",u"ŝin"],u"he":[u"אבל",u"או",u"אולי",u"אותה",u"אותו",u"אותי",u"אותך",u"אותם",u"אותן",u"אותנו",u"אז",u"אחר",u"אחרות",u"אחרי",u"אחריכן",u"אחרים",u"אחרת",u"אי",u"איזה",u"איך",u"אין",u"איפה",u"איתה",u"איתו",u"איתי",u"איתך",u"איתכם",u"איתכן",u"איתם",u"איתן",u"איתנו",u"אך",u"אל",u"אלה",u"אלו",u"אם",u"אנחנו",u"אני",u"אס",u"אף",u"אצל",u"אשר",u"את",u"אתה",u"אתכם",u"אתכן",u"אתם",u"אתן",u"באיזומידה",u"באמצע",u"באמצעות",u"בגלל",u"בין",u"בלי",u"במידה",u"במקוםשבו",u"ברם",u"בשביל",u"בשעהש",u"בתוך",u"גם",u"דרך",u"הוא",u"היא",u"היה",u"היכן",u"היתה",u"היתי",u"הם",u"הן",u"הנה",u"הסיבהשבגללה",u"הרי",u"ואילו",u"ואת",u"זאת",u"זה",u"זות",u"יהיה",u"יוכל",u"יוכלו",u"יותרמדי",u"יכול",u"יכולה",u"יכולות",u"יכולים",u"יכל",u"יכלה",u"יכלו",u"יש",u"כאן",u"כאשר",u"כולם",u"כולן",u"כזה",u"כי",u"כיצד",u"כך",u"ככה",u"כל",u"כלל",u"כמו",u"כן",u"כפי",u"כש",u"לא",u"לאו",u"לאיזותכלית",u"לאן",u"לבין",u"לה",u"להיות",u"להם",u"להן",u"לו",u"לי",u"לכם",u"לכן",u"למה",u"למטה",u"למעלה",u"למקוםשבו",u"למרות",u"לנו",u"לעבר",u"לעיכן",u"לפיכך",u"לפני",u"מאד",u"מאחורי",u"מאיזוסיבה",u"מאין",u"מאיפה",u"מבלי",u"מבעד",u"מדוע",u"מה",u"מהיכן",u"מול",u"מחוץ",u"מי",u"מכאן",u"מכיוון",u"מלבד",u"מן",u"מנין",u"מסוגל",u"מעט",u"מעטים",u"מעל",u"מצד",u"מקוםבו",u"מתחת",u"מתי",u"נגד",u"נגר",u"נו",u"עד",u"עז",u"על",u"עלי",u"עליה",u"עליהם",u"עליהן",u"עליו",u"עליך",u"עליכם",u"עלינו",u"עם",u"עצמה",u"עצמהם",u"עצמהן",u"עצמו",u"עצמי",u"עצמם",u"עצמן",u"עצמנו",u"פה",u"רק",u"שוב",u"של",u"שלה",u"שלהם",u"שלהן",u"שלו",u"שלי",u"שלך",u"שלכה",u"שלכם",u"שלכן",u"שלנו",u"שם",u"תהיה",u"תחת"],u"la":[u"a",u"ab",u"ac",u"ad",u"at",u"atque",u"aut",u"autem",u"cum",u"de",u"dum",u"e",u"erant",u"erat",u"est",u"et",u"etiam",u"ex",u"haec",u"hic",u"hoc",u"in",u"ita",u"me",u"nec",u"neque",u"non",u"per",u"qua",u"quae",u"quam",u"qui",u"quibus",u"quidem",u"quo",u"quod",u"re",u"rebus",u"rem",u"res",u"sed",u"si",u"sic",u"sunt",u"tamen",u"tandem",u"te",u"ut",u"vel"],u"sk":[u"a",u"aby",u"aj",u"ako",u"aký",u"ale",u"alebo",u"ani",u"avšak",u"ba",u"bez",u"buï",u"cez",u"do",u"ho",u"hoci",u"i",u"ich",u"im",u"ja",u"jeho",u"jej",u"jemu",u"ju",u"k",u"kam",u"kde",u"kedže",u"keï",u"kto",u"ktorý",u"ku",u"lebo",u"ma",u"mi",u"mne",u"mnou",u"mu",u"my",u"mòa",u"môj",u"na",u"nad",u"nami",u"neho",u"nej",u"nemu",u"nich",u"nielen",u"nim",u"no",u"nám",u"nás",u"náš",u"ním",u"o",u"od",u"on",u"ona",u"oni",u"ono",u"ony",u"po",u"pod",u"pre",u"pred",u"pri",u"s",u"sa",u"seba",u"sem",u"so",u"svoj",u"taký",u"tam",u"teba",u"tebe",u"tebou",u"tej",u"ten",u"ti",u"tie",u"to",u"toho",u"tomu",u"tou",u"tvoj",u"ty",u"tá",u"tým",u"v",u"vami",u"veï",u"vo",u"vy",u"vám",u"vás",u"váš",u"však",u"z",u"za",u"zo",u"a",u"èi",u"èo",u"èí",u"òom",u"òou",u"òu",u"že"],u"sl":[u"a",u"ali",u"april",u"avgust",u"b",u"bi",u"bil",u"bila",u"bile",u"bili",u"bilo",u"biti",u"blizu",u"bo",u"bodo",u"bojo",u"bolj",u"bom",u"bomo",u"boste",u"bova",u"boš",u"brez",u"c",u"cel",u"cela",u"celi",u"celo",u"d",u"da",u"daleč",u"dan",u"danes",u"datum",u"december",u"deset",u"deseta",u"deseti",u"deseto",u"devet",u"deveta",u"deveti",u"deveto",u"do",u"dober",u"dobra",u"dobri",u"dobro",u"dokler",u"dol",u"dolg",u"dolga",u"dolgi",u"dovolj",u"drug",u"druga",u"drugi",u"drugo",u"dva",u"dve",u"e",u"eden",u"en",u"ena",u"ene",u"eni",u"enkrat",u"eno",u"etc.",u"f",u"februar",u"g",u"g.",u"ga",u"ga.",u"gor",u"gospa",u"gospod",u"h",u"halo",u"i",u"idr.",u"ii",u"iii",u"in",u"iv",u"ix",u"iz",u"j",u"januar",u"jaz",u"je",u"ji",u"jih",u"jim",u"jo",u"julij",u"junij",u"jutri",u"k",u"kadarkoli",u"kaj",u"kajti",u"kako",u"kakor",u"kamor",u"kamorkoli",u"kar",u"karkoli",u"katerikoli",u"kdaj",u"kdo",u"kdorkoli",u"ker",u"ki",u"kje",u"kjer",u"kjerkoli",u"ko",u"koder",u"koderkoli",u"koga",u"komu",u"kot",u"kratek",u"kratka",u"kratke",u"kratki",u"l",u"lahka",u"lahke",u"lahki",u"lahko",u"le",u"lep",u"lepa",u"lepe",u"lepi",u"lepo",u"leto",u"m",u"maj",u"majhen",u"majhna",u"majhni",u"malce",u"malo",u"manj",u"marec",u"me",u"med",u"medtem",u"mene",u"mesec",u"mi",u"midva",u"midve",u"mnogo",u"moj",u"moja",u"moje",u"mora",u"morajo",u"moram",u"moramo",u"morate",u"moraš",u"morem",u"mu",u"n",u"na",u"nad",u"naj",u"najina",u"najino",u"najmanj",u"naju",u"največ",u"nam",u"narobe",u"nas",u"nato",u"nazaj",u"naš",u"naša",u"naše",u"ne",u"nedavno",u"nedelja",u"nek",u"neka",u"nekaj",u"nekatere",u"nekateri",u"nekatero",u"nekdo",u"neke",u"nekega",u"neki",u"nekje",u"neko",u"nekoga",u"nekoč",u"ni",u"nikamor",u"nikdar",u"nikjer",u"nikoli",u"nič",u"nje",u"njega",u"njegov",u"njegova",u"njegovo",u"njej",u"njemu",u"njen",u"njena",u"njeno",u"nji",u"njih",u"njihov",u"njihova",u"njihovo",u"njiju",u"njim",u"njo",u"njun",u"njuna",u"njuno",u"no",u"nocoj",u"november",u"npr.",u"o",u"ob",u"oba",u"obe",u"oboje",u"od",u"odprt",u"odprta",u"odprti",u"okoli",u"oktober",u"on",u"onadva",u"one",u"oni",u"onidve",u"osem",u"osma",u"osmi",u"osmo",u"oz.",u"p",u"pa",u"pet",u"peta",u"petek",u"peti",u"peto",u"po",u"pod",u"pogosto",u"poleg",u"poln",u"polna",u"polni",u"polno",u"ponavadi",u"ponedeljek",u"ponovno",u"potem",u"povsod",u"pozdravljen",u"pozdravljeni",u"prav",u"prava",u"prave",u"pravi",u"pravo",u"prazen",u"prazna",u"prazno",u"prbl.",u"precej",u"pred",u"prej",u"preko",u"pri",u"pribl.",u"približno",u"primer",u"pripravljen",u"pripravljena",u"pripravljeni",u"proti",u"prva",u"prvi",u"prvo",u"r",u"ravno",u"redko",u"res",u"reč",u"s",u"saj",u"sam",u"sama",u"same",u"sami",u"samo",u"se",u"sebe",u"sebi",u"sedaj",u"sedem",u"sedma",u"sedmi",u"sedmo",u"sem",u"september",u"seveda",u"si",u"sicer",u"skoraj",u"skozi",u"slab",u"smo",u"so",u"sobota",u"spet",u"sreda",u"srednja",u"srednji",u"sta",u"ste",u"stran",u"stvar",u"sva",u"t",u"ta",u"tak",u"taka",u"take",u"taki",u"tako",u"takoj",u"tam",u"te",u"tebe",u"tebi",u"tega",u"težak",u"težka",u"težki",u"težko",u"ti",u"tista",u"tiste",u"tisti",u"tisto",u"tj.",u"tja",u"to",u"toda",u"torek",u"tretja",u"tretje",u"tretji",u"tri",u"tu",u"tudi",u"tukaj",u"tvoj",u"tvoja",u"tvoje",u"u",u"v",u"vaju",u"vam",u"vas",u"vaš",u"vaša",u"vaše",u"ve",u"vedno",u"velik",u"velika",u"veliki",u"veliko",u"vendar",u"ves",u"več",u"vi",u"vidva",u"vii",u"viii",u"visok",u"visoka",u"visoke",u"visoki",u"vsa",u"vsaj",u"vsak",u"vsaka",u"vsakdo",u"vsake",u"vsaki",u"vsakomur",u"vse",u"vsega",u"vsi",u"vso",u"včasih",u"včeraj",u"x",u"z",u"za",u"zadaj",u"zadnji",u"zakaj",u"zaprta",u"zaprti",u"zaprto",u"zdaj",u"zelo",u"zunaj",u"č",u"če",u"često",u"četrta",u"četrtek",u"četrti",u"četrto",u"čez",u"čigav",u"š",u"šest",u"šesta",u"šesti",u"šesto",u"štiri",u"ž",u"že"],u"br":[u"a",u"ainda",u"alem",u"ambas",u"ambos",u"antes",u"ao",u"aonde",u"aos",u"apos",u"aquele",u"aqueles",u"as",u"assim",u"com",u"como",u"contra",u"contudo",u"cuja",u"cujas",u"cujo",u"cujos",u"da",u"das",u"de",u"dela",u"dele",u"deles",u"demais",u"depois",u"desde",u"desta",u"deste",u"dispoe",u"dispoem",u"diversa",u"diversas",u"diversos",u"do",u"dos",u"durante",u"e",u"ela",u"elas",u"ele",u"eles",u"em",u"entao",u"entre",u"essa",u"essas",u"esse",u"esses",u"esta",u"estas",u"este",u"estes",u"ha",u"isso",u"isto",u"logo",u"mais",u"mas",u"mediante",u"menos",u"mesma",u"mesmas",u"mesmo",u"mesmos",u"na",u"nao",u"nas",u"nem",u"nesse",u"neste",u"nos",u"o",u"os",u"ou",u"outra",u"outras",u"outro",u"outros",u"pelas",u"pelo",u"pelos",u"perante",u"pois",u"por",u"porque",u"portanto",u"propios",u"proprio",u"quais",u"qual",u"qualquer",u"quando",u"quanto",u"que",u"quem",u"quer",u"se",u"seja",u"sem",u"sendo",u"seu",u"seus",u"sob",u"sobre",u"sua",u"suas",u"tal",u"tambem",u"teu",u"teus",u"toda",u"todas",u"todo",u"todos",u"tua",u"tuas",u"tudo",u"um",u"uma",u"umas",u"uns"],u"ca":[u"a",u"abans",u"ací",u"ah",u"així",u"això",u"al",u"aleshores",u"algun",u"alguna",u"algunes",u"alguns",u"alhora",u"allà",u"allí",u"allò",u"als",u"altra",u"altre",u"altres",u"amb",u"ambdues",u"ambdós",u"apa",u"aquell",u"aquella",u"aquelles",u"aquells",u"aquest",u"aquesta",u"aquestes",u"aquests",u"aquí",u"baix",u"cada",u"cadascuna",u"cadascunes",u"cadascuns",u"cadascú",u"com",u"contra",u"d'un",u"d'una",u"d'unes",u"d'uns",u"dalt",u"de",u"del",u"dels",u"des",u"després",u"dins",u"dintre",u"donat",u"doncs",u"durant",u"e",u"eh",u"el",u"els",u"em",u"en",u"encara",u"ens",u"entre",u"eren",u"es",u"esta",u"estaven",u"esteu",u"està",u"estàvem",u"estàveu",u"et",u"etc",u"ets",u"fins",u"fora",u"gairebé",u"ha",u"han",u"has",u"havia",u"he",u"hem",u"heu",u"hi",u"ho",u"i",u"igual",u"iguals",u"ja",u"l'hi",u"la",u"les",u"li",u"li'n",u"llavors",u"m'he",u"ma",u"mal",u"malgrat",u"mateix",u"mateixa",u"mateixes",u"mateixos",u"me",u"mentre",u"meu",u"meus",u"meva",u"meves",u"molt",u"molta",u"moltes",u"molts",u"mon",u"mons",u"més",u"n'he",u"n'hi",u"ne",u"ni",u"no",u"nogensmenys",u"només",u"nosaltres",u"nostra",u"nostre",u"nostres",u"o",u"oh",u"oi",u"on",u"pas",u"pel",u"pels",u"per",u"perquè",u"però",u"poc",u"poca",u"pocs",u"poques",u"potser",u"propi",u"qual",u"quals",u"quan",u"quant",u"que",u"quelcom",u"qui",u"quin",u"quina",u"quines",u"quins",u"què",u"s'ha",u"s'han",u"sa",u"semblant",u"semblants",u"ses",u"seu",u"seus",u"seva",u"seves",u"si",u"sobre",u"sobretot",u"solament",u"sols",u"son",u"sons",u"sota",u"sou",u"sóc",u"són",u"t'ha",u"t'han",u"t'he",u"ta",u"tal",u"també",u"tampoc",u"tan",u"tant",u"tanta",u"tantes",u"teu",u"teus",u"teva",u"teves",u"ton",u"tons",u"tot",u"tota",u"totes",u"tots",u"un",u"una",u"unes",u"uns",u"us",u"va",u"vaig",u"vam",u"van",u"vas",u"veu",u"vosaltres",u"vostra",u"vostre",u"vostres",u"érem",u"éreu",u"és"],u"cs":[u"a",u"aby",u"ahoj",u"aj",u"ale",u"anebo",u"ani",u"ano",u"asi",u"aspoň",u"atd",u"atp",u"ačkoli",u"až",u"bez",u"beze",u"blízko",u"bohužel",u"brzo",u"bude",u"budem",u"budeme",u"budete",u"budeš",u"budou",u"budu",u"by",u"byl",u"byla",u"byli",u"bylo",u"byly",u"bys",u"být",u"během",u"chce",u"chceme",u"chcete",u"chceš",u"chci",u"chtít",u"chtějí",u"chut'",u"chuti",u"co",u"což",u"cz",u"daleko",u"další",u"den",u"deset",u"devatenáct",u"devět",u"dnes",u"do",u"dobrý",u"docela",u"dva",u"dvacet",u"dvanáct",u"dvě",u"dál",u"dále",u"děkovat",u"děkujeme",u"děkuji",u"ho",u"hodně",u"i",u"jak",u"jakmile",u"jako",u"jakož",u"jde",u"je",u"jeden",u"jedenáct",u"jedna",u"jedno",u"jednou",u"jedou",u"jeho",u"jehož",u"jej",u"jejich",u"její",u"jelikož",u"jemu",u"jen",u"jenom",u"jestli",u"jestliže",u"ještě",u"jež",u"ji",u"jich",u"jimi",u"jinak",u"jiné",u"již",u"jsem",u"jseš",u"jsi",u"jsme",u"jsou",u"jste",u"já",u"jí",u"jím",u"jíž",u"k",u"kam",u"kde",u"kdo",u"kdy",u"když",u"ke",u"kolik",u"kromě",u"kterou",u"která",u"které",u"který",u"kteří",u"kvůli",u"mají",u"mezi",u"mi",u"mne",u"mnou",u"mně",u"moc",u"mohl",u"mohou",u"moje",u"moji",u"možná",u"musí",u"my",u"má",u"málo",u"mám",u"máme",u"máte",u"máš",u"mé",u"mí",u"mít",u"mě",u"můj",u"může",u"na",u"nad",u"nade",u"napište",u"naproti",u"načež",u"naše",u"naši",u"ne",u"nebo",u"nebyl",u"nebyla",u"nebyli",u"nebyly",u"nedělají",u"nedělá",u"nedělám",u"neděláme",u"neděláte",u"neděláš",u"neg",u"nejsi",u"nejsou",u"nemají",u"nemáme",u"nemáte",u"neměl",u"není",u"nestačí",u"nevadí",u"než",u"nic",u"nich",u"nimi",u"nové",u"nový",u"nula",u"nám",u"námi",u"nás",u"náš",u"ním",u"ně",u"něco",u"nějak",u"někde",u"někdo",u"němu",u"němuž",u"o",u"od",u"ode",u"on",u"ona",u"oni",u"ono",u"ony",u"osm",u"osmnáct",u"pak",u"patnáct",u"po",u"pod",u"podle",u"pokud",u"potom",u"pouze",u"pozdě",u"pořád",u"pravé",u"pro",u"prostě",u"prosím",u"proti",u"proto",u"protože",u"proč",u"první",u"pta",u"pět",u"před",u"přes",u"přese",u"při",u"přičemž",u"re",u"rovně",u"s",u"se",u"sedm",u"sedmnáct",u"si",u"skoro",u"smí",u"smějí",u"snad",u"spolu",u"sta",u"sto",u"strana",u"sté",u"své",u"svých",u"svým",u"svými",u"ta",u"tady",u"tak",u"takhle",u"taky",u"také",u"takže",u"tam",u"tamhle",u"tamhleto",u"tamto",u"tato",u"tebe",u"tebou",u"ted'",u"tedy",u"ten",u"tento",u"teto",u"ti",u"tipy",u"tisíc",u"tisíce",u"to",u"tobě",u"tohle",u"toho",u"tohoto",u"tom",u"tomto",u"tomu",u"tomuto",u"toto",u"trošku",u"tu",u"tuto",u"tvoje",u"tvá",u"tvé",u"tvůj",u"ty",u"tyto",u"téma",u"tím",u"tímto",u"tě",u"těm",u"těmu",u"třeba",u"tři",u"třináct",u"u",u"určitě",u"už",u"v",u"vaše",u"vaši",u"ve",u"vedle",u"večer",u"vlastně",u"vy",u"vám",u"vámi",u"vás",u"váš",u"více",u"však",u"všechno",u"všichni",u"vůbec",u"vždy",u"z",u"za",u"zatímco",u"zač",u"zda",u"zde",u"ze",u"zprávy",u"zpět",u"čau",u"či",u"článku",u"články",u"čtrnáct",u"čtyři",u"šest",u"šestnáct",u"že"],u"el":[u"αλλα",u"αν",u"αντι",u"απο",u"αυτα",u"αυτεσ",u"αυτη",u"αυτο",u"αυτοι",u"αυτοσ",u"αυτουσ",u"αυτων",u"για",u"δε",u"δεν",u"εαν",u"ειμαι",u"ειμαστε",u"ειναι",u"εισαι",u"ειστε",u"εκεινα",u"εκεινεσ",u"εκεινη",u"εκεινο",u"εκεινοι",u"εκεινοσ",u"εκεινουσ",u"εκεινων",u"ενω",u"επι",u"η",u"θα",u"ισωσ",u"κ",u"και",u"κατα",u"κι",u"μα",u"με",u"μετα",u"μη",u"μην",u"να",u"ο",u"οι",u"ομωσ",u"οπωσ",u"οσο",u"οτι",u"παρα",u"ποια",u"ποιεσ",u"ποιο",u"ποιοι",u"ποιοσ",u"ποιουσ",u"ποιων",u"που",u"προσ",u"πωσ",u"σε",u"στη",u"στην",u"στο",u"στον",u"τα",u"την",u"τησ",u"το",u"τον",u"τοτε",u"του",u"των",u"ωσ"],u"eu":[u"al",u"anitz",u"arabera",u"asko",u"baina",u"bat",u"batean",u"batek",u"bati",u"batzuei",u"batzuek",u"batzuetan",u"batzuk",u"bera",u"beraiek",u"berau",u"berauek",u"bere",u"berori",u"beroriek",u"beste",u"bezala",u"da",u"dago",u"dira",u"ditu",u"du",u"dute",u"edo",u"egin",u"ere",u"eta",u"eurak",u"ez",u"gainera",u"gu",u"gutxi",u"guzti",u"haiei",u"haiek",u"haietan",u"hainbeste",u"hala",u"han",u"handik",u"hango",u"hara",u"hari",u"hark",u"hartan",u"hau",u"hauei",u"hauek",u"hauetan",u"hemen",u"hemendik",u"hemengo",u"hi",u"hona",u"honek",u"honela",u"honetan",u"honi",u"hor",u"hori",u"horiei",u"horiek",u"horietan",u"horko",u"horra",u"horrek",u"horrela",u"horretan",u"horri",u"hortik",u"hura",u"izan",u"ni",u"noiz",u"nola",u"non",u"nondik",u"nongo",u"nor",u"nora",u"ze",u"zein",u"zen",u"zenbait",u"zenbat",u"zer",u"zergatik",u"ziren",u"zituen",u"zu",u"zuek",u"zuen",u"zuten"],u"ga":[u"a",u"ach",u"ag",u"agus",u"an",u"aon",u"ar",u"arna",u"as",u"b'",u"ba",u"beirt",u"bhúr",u"caoga",u"ceathair",u"ceathrar",u"chomh",u"chtó",u"chuig",u"chun",u"cois",u"céad",u"cúig",u"cúigear",u"d'",u"daichead",u"dar",u"de",u"deich",u"deichniúr",u"den",u"dhá",u"do",u"don",u"dtí",u"dá",u"dár",u"dó",u"faoi",u"faoin",u"faoina",u"faoinár",u"fara",u"fiche",u"gach",u"gan",u"go",u"gur",u"haon",u"hocht",u"i",u"iad",u"idir",u"in",u"ina",u"ins",u"inár",u"is",u"le",u"leis",u"lena",u"lenár",u"m'",u"mar",u"mo",u"mé",u"na",u"nach",u"naoi",u"naonúr",u"ná",u"ní",u"níor",u"nó",u"nócha",u"ocht",u"ochtar",u"os",u"roimh",u"sa",u"seacht",u"seachtar",u"seachtó",u"seasca",u"seisear",u"siad",u"sibh",u"sinn",u"sna",u"sé",u"sí",u"tar",u"thar",u"thú",u"triúr",u"trí",u"trína",u"trínár",u"tríocha",u"tú",u"um",u"ár",u"é",u"éis",u"í",u"ó",u"ón",u"óna",u"ónár"],u"gl":[u"a",u"alí",u"ao",u"aos",u"aquel",u"aquela",u"aquelas",u"aqueles",u"aquilo",u"aquí",u"as",u"así",u"aínda",u"ben",u"cando",u"che",u"co",u"coa",u"coas",u"comigo",u"con",u"connosco",u"contigo",u"convosco",u"cos",u"cun",u"cunha",u"cunhas",u"cuns",u"da",u"dalgunha",u"dalgunhas",u"dalgún",u"dalgúns",u"das",u"de",u"del",u"dela",u"delas",u"deles",u"desde",u"deste",u"do",u"dos",u"dun",u"dunha",u"dunhas",u"duns",u"e",u"el",u"ela",u"elas",u"eles",u"en",u"era",u"eran",u"esa",u"esas",u"ese",u"eses",u"esta",u"estaba",u"estar",u"este",u"estes",u"estiven",u"estou",u"está",u"están",u"eu",u"facer",u"foi",u"foron",u"fun",u"había",u"hai",u"iso",u"isto",u"la",u"las",u"lle",u"lles",u"lo",u"los",u"mais",u"me",u"meu",u"meus",u"min",u"miña",u"miñas",u"moi",u"na",u"nas",u"neste",u"nin",u"no",u"non",u"nos",u"nosa",u"nosas",u"noso",u"nosos",u"nun",u"nunha",u"nunhas",u"nuns",u"nós",u"o",u"os",u"ou",u"para",u"pero",u"pode",u"pois",u"pola",u"polas",u"polo",u"polos",u"por",u"que",u"se",u"senón",u"ser",u"seu",u"seus",u"sexa",u"sido",u"sobre",u"súa",u"súas",u"tamén",u"tan",u"te",u"ten",u"ter",u"teu",u"teus",u"teñen",u"teño",u"ti",u"tido",u"tiven",u"tiña",u"túa",u"túas",u"un",u"unha",u"unhas",u"uns",u"vos",u"vosa",u"vosas",u"voso",u"vosos",u"vós",u"á",u"é",u"ó",u"ós"],u"hy":[u"այդ",u"այլ",u"այն",u"այս",u"դու",u"դուք",u"եմ",u"են",u"ենք",u"ես",u"եք",u"է",u"էի",u"էին",u"էինք",u"էիր",u"էիք",u"էր",u"ըստ",u"թ",u"ի",u"ին",u"իսկ",u"իր",u"կամ",u"համար",u"հետ",u"հետո",u"մենք",u"մեջ",u"մի",u"ն",u"նա",u"նաև",u"նրա",u"նրանք",u"որ",u"որը",u"որոնք",u"որպես",u"ու",u"ում",u"պիտի",u"վրա",u"և"],u"id":[u"ada",u"adalah",u"adanya",u"adapun",u"agak",u"agaknya",u"agar",u"akan",u"akankah",u"akhirnya",u"aku",u"akulah",u"amat",u"amatlah",u"anda",u"andalah",u"antar",u"antara",u"antaranya",u"apa",u"apaan",u"apabila",u"apakah",u"apalagi",u"apatah",u"atau",u"ataukah",u"ataupun",u"bagai",u"bagaikan",u"bagaimana",u"bagaimanakah",u"bagaimanapun",u"bagi",u"bahkan",u"bahwa",u"bahwasanya",u"banyak",u"beberapa",u"begini",u"beginian",u"beginikah",u"beginilah",u"begitu",u"begitukah",u"begitulah",u"begitupun",u"belum",u"belumlah",u"berapa",u"berapakah",u"berapalah",u"berapapun",u"bermacam",u"bersama",u"betulkah",u"biasa",u"biasanya",u"bila",u"bilakah",u"bisa",u"bisakah",u"boleh",u"bolehkah",u"bolehlah",u"buat",u"bukan",u"bukankah",u"bukanlah",u"bukannya",u"cuma",u"dahulu",u"dalam",u"dan",u"dapat",u"dari",u"daripada",u"dekat",u"demi",u"demikian",u"demikianlah",u"dengan",u"depan",u"di",u"dia",u"dialah",u"diantara",u"diantaranya",u"dikarenakan",u"dini",u"diri",u"dirinya",u"disini",u"disinilah",u"dong",u"dulu",u"enggak",u"enggaknya",u"entah",u"entahlah",u"hal",u"hampir",u"hanya",u"hanyalah",u"harus",u"haruslah",u"harusnya",u"hendak",u"hendaklah",u"hendaknya",u"hingga",u"ia",u"ialah",u"ibarat",u"ingin",u"inginkah",u"inginkan",u"ini",u"inikah",u"inilah",u"itu",u"itukah",u"itulah",u"jangan",u"jangankan",u"janganlah",u"jika",u"jikalau",u"juga",u"justru",u"kala",u"kalau",u"kalaulah",u"kalaupun",u"kalian",u"kami",u"kamilah",u"kamu",u"kamulah",u"kan",u"kapan",u"kapankah",u"kapanpun",u"karena",u"karenanya",u"ke",u"kecil",u"kemudian",u"kenapa",u"kepada",u"kepadanya",u"ketika",u"khususnya",u"kini",u"kinilah",u"kiranya",u"kita",u"kitalah",u"kok",u"lagi",u"lagian",u"lah",u"lain",u"lainnya",u"lalu",u"lama",u"lamanya",u"lebih",u"macam",u"maka",u"makanya",u"makin",u"malah",u"malahan",u"mampu",u"mampukah",u"mana",u"manakala",u"manalagi",u"masih",u"masihkah",u"masing",u"mau",u"maupun",u"melainkan",u"melalui",u"memang",u"mengapa",u"mereka",u"merekalah",u"merupakan",u"meski",u"meskipun",u"mungkin",u"mungkinkah",u"nah",u"namun",u"nanti",u"nantinya",u"nyaris",u"oleh",u"olehnya",u"pada",u"padahal",u"padanya",u"paling",u"pantas",u"para",u"pasti",u"pastilah",u"per",u"percuma",u"pernah",u"pula",u"pun",u"rupanya",u"saat",u"saatnya",u"saja",u"sajalah",u"saling",u"sama",u"sambil",u"sampai",u"sana",u"sangat",u"sangatlah",u"saya",u"sayalah",u"se",u"sebab",u"sebabnya",u"sebagai",u"sebagaimana",u"sebagainya",u"sebaliknya",u"sebanyak",u"sebegini",u"sebegitu",u"sebelum",u"sebelumnya",u"sebenarnya",u"seberapa",u"sebetulnya",u"sebisanya",u"sebuah",u"sedang",u"sedangkan",u"sedemikian",u"sedikit",u"sedikitnya",u"segala",u"segalanya",u"segera",u"seharusnya",u"sehingga",u"sejak",u"sejenak",u"sekali",u"sekalian",u"sekaligus",u"sekalipun",u"sekarang",u"seketika",u"sekiranya",u"sekitar",u"sekitarnya",u"sela",u"selagi",u"selain",u"selaku",u"selalu",u"selama",u"selamanya",u"seluruh",u"seluruhnya",u"semacam",u"semakin",u"semasih",u"semaunya",u"sementara",u"sempat",u"semua",u"semuanya",u"semula",u"sendiri",u"sendirinya",u"seolah",u"seorang",u"sepanjang",u"sepantasnya",u"sepantasnyalah",u"seperti",u"sepertinya",u"sering",u"seringnya",u"serta",u"serupa",u"sesaat",u"sesama",u"sesegera",u"sesekali",u"seseorang",u"sesuatu",u"sesuatunya",u"sesudah",u"sesudahnya",u"setelah",u"seterusnya",u"setiap",u"setidaknya",u"sewaktu",u"siapa",u"siapakah",u"siapapun",u"sini",u"sinilah",u"suatu",u"sudah",u"sudahkah",u"sudahlah",u"supaya",u"tadi",u"tadinya",u"tak",u"tanpa",u"tapi",u"telah",u"tentang",u"tentu",u"tentulah",u"tentunya",u"terdiri",u"terhadap",u"terhadapnya",u"terlalu",u"terlebih",u"tersebut",u"tersebutlah",u"tertentu",u"tetapi",u"tiap",u"tidak",u"tidakkah",u"tidaklah",u"toh",u"waduh",u"wah",u"wahai",u"walau",u"walaupun",u"wong",u"yaitu",u"yakni",u"yang"],u"ja":[u"あっ",u"あり",u"ある",u"い",u"いう",u"いる",u"う",u"うち",u"お",u"および",u"おり",u"か",u"かつて",u"から",u"が",u"き",u"ここ",u"こと",u"この",u"これ",u"これら",u"さ",u"さらに",u"し",u"しかし",u"する",u"ず",u"せ",u"せる",u"そして",u"その",u"その他",u"その後",u"それ",u"それぞれ",u"た",u"ただし",u"たち",u"ため",u"たり",u"だ",u"だっ",u"つ",u"て",u"で",u"でき",u"できる",u"です",u"では",u"でも",u"と",u"という",u"といった",u"とき",u"ところ",u"として",u"とともに",u"とも",u"と共に",u"な",u"ない",u"なお",u"なかっ",u"ながら",u"なく",u"なっ",u"など",u"なら",u"なり",u"なる",u"に",u"において",u"における",u"について",u"にて",u"によって",u"により",u"による",u"に対して",u"に対する",u"に関する",u"の",u"ので",u"のみ",u"は",u"ば",u"へ",u"ほか",u"ほとんど",u"ほど",u"ます",u"また",u"または",u"まで",u"も",u"もの",u"ものの",u"や",u"よう",u"より",u"ら",u"られ",u"られる",u"れ",u"れる",u"を",u"ん",u"及び",u"特に"],u"lv":[u"aiz",u"ap",u"apakš",u"apakšpus",u"ar",u"arī",u"augšpus",u"bet",u"bez",u"bija",u"biji",u"biju",u"bijām",u"bijāt",u"būs",u"būsi",u"būsiet",u"būsim",u"būt",u"būšu",u"caur",u"diemžēl",u"diezin",u"droši",u"dēļ",u"esam",u"esat",u"esi",u"esmu",u"gan",u"gar",u"iekam",u"iekams",u"iekām",u"iekāms",u"iekš",u"iekšpus",u"ik",u"ir",u"it",u"itin",u"iz",u"ja",u"jau",u"jeb",u"jebšu",u"jel",u"jo",u"jā",u"ka",u"kamēr",u"kaut",u"kolīdz",u"kopš",u"kā",u"kļuva",u"kļuvi",u"kļuvu",u"kļuvām",u"kļuvāt",u"kļūs",u"kļūsi",u"kļūsiet",u"kļūsim",u"kļūst",u"kļūstam",u"kļūstat",u"kļūsti",u"kļūstu",u"kļūt",u"kļūšu",u"labad",u"lai",u"lejpus",u"līdz",u"līdzko",u"ne",u"nebūt",u"nedz",u"nekā",u"nevis",u"nezin",u"no",u"nu",u"nē",u"otrpus",u"pa",u"par",u"pat",u"pie",u"pirms",u"pret",u"priekš",u"pār",u"pēc",u"starp",u"tad",u"tak",u"tapi",u"taps",u"tapsi",u"tapsiet",u"tapsim",u"tapt",u"tapāt",u"tapšu",u"taču",u"te",u"tiec",u"tiek",u"tiekam",u"tiekat",u"tieku",u"tik",u"tika",u"tikai",u"tiki",u"tikko",u"tiklab",u"tiklīdz",u"tiks",u"tiksiet",u"tiksim",u"tikt",u"tiku",u"tikvien",u"tikām",u"tikāt",u"tikšu",u"tomēr",u"topat",u"turpretim",u"turpretī",u"tā",u"tādēļ",u"tālab",u"tāpēc",u"un",u"uz",u"vai",u"var",u"varat",u"varēja",u"varēji",u"varēju",u"varējām",u"varējāt",u"varēs",u"varēsi",u"varēsiet",u"varēsim",u"varēt",u"varēšu",u"vien",u"virs",u"virspus",u"vis",u"viņpus",u"zem",u"ārpus",u"šaipus"],u"th":[u"กล่าว",u"กว่า",u"กัน",u"กับ",u"การ",u"ก็",u"ก่อน",u"ขณะ",u"ขอ",u"ของ",u"ขึ้น",u"คง",u"ครั้ง",u"ความ",u"คือ",u"จะ",u"จัด",u"จาก",u"จึง",u"ช่วง",u"ซึ่ง",u"ดัง",u"ด้วย",u"ด้าน",u"ตั้ง",u"ตั้งแต่",u"ตาม",u"ต่อ",u"ต่าง",u"ต่างๆ",u"ต้อง",u"ถึง",u"ถูก",u"ถ้า",u"ทั้ง",u"ทั้งนี้",u"ทาง",u"ที่",u"ที่สุด",u"ทุก",u"ทํา",u"ทําให้",u"นอกจาก",u"นัก",u"นั้น",u"นี้",u"น่า",u"นํา",u"บาง",u"ผล",u"ผ่าน",u"พบ",u"พร้อม",u"มา",u"มาก",u"มี",u"ยัง",u"รวม",u"ระหว่าง",u"รับ",u"ราย",u"ร่วม",u"ลง",u"วัน",u"ว่า",u"สุด",u"ส่ง",u"ส่วน",u"สําหรับ",u"หนึ่ง",u"หรือ",u"หลัง",u"หลังจาก",u"หลาย",u"หาก",u"อยาก",u"อยู่",u"อย่าง",u"ออก",u"อะไร",u"อาจ",u"อีก",u"เขา",u"เข้า",u"เคย",u"เฉพาะ",u"เช่น",u"เดียว",u"เดียวกัน",u"เนื่องจาก",u"เปิด",u"เปิดเผย",u"เป็น",u"เป็นการ",u"เพราะ",u"เพื่อ",u"เมื่อ",u"เรา",u"เริ่ม",u"เลย",u"เห็น",u"เอง",u"แต่",u"แบบ",u"แรก",u"และ",u"แล้ว",u"แห่ง",u"โดย",u"ใน",u"ให้",u"ได้",u"ไป",u"ไม่",u"ไว้"],u"ar":[u"،",u"أ",u"ا",u"اثر",u"اجل",u"احد",u"اخرى",u"اذا",u"اربعة",u"اطار",u"اعادة",u"اعلنت",u"اف",u"اكثر",u"اكد",u"الا",u"الاخيرة",u"الان",u"الاول",u"الاولى",u"التى",u"التي",u"الثاني",u"الثانية",u"الذاتي",u"الذى",u"الذي",u"الذين",u"السابق",u"الف",u"الماضي",u"المقبل",u"الوقت",u"الى",u"اليوم",u"اما",u"امام",u"امس",u"ان",u"انه",u"انها",u"او",u"اول",u"اي",u"ايار",u"ايام",u"ايضا",u"ب",u"باسم",u"بان",u"برس",u"بسبب",u"بشكل",u"بعد",u"بعض",u"بن",u"به",u"بها",u"بين",u"تم",u"ثلاثة",u"ثم",u"جميع",u"حاليا",u"حتى",u"حوالى",u"حول",u"حيث",u"حين",u"خلال",u"دون",u"ذلك",u"زيارة",u"سنة",u"سنوات",u"شخصا",u"صباح",u"صفر",u"ضد",u"ضمن",u"عام",u"عاما",u"عدة",u"عدد",u"عدم",u"عشر",u"عشرة",u"على",u"عليه",u"عليها",u"عن",u"عند",u"عندما",u"غدا",u"غير",u"ـ",u"ف",u"فان",u"فى",u"في",u"فيه",u"فيها",u"قال",u"قبل",u"قد",u"قوة",u"كان",u"كانت",u"كل",u"كلم",u"كما",u"لا",u"لدى",u"لقاء",u"لكن",u"للامم",u"لم",u"لن",u"له",u"لها",u"لوكالة",u"ما",u"مايو",u"مساء",u"مع",u"مقابل",u"مليار",u"مليون",u"من",u"منذ",u"منها",u"نحو",u"نفسه",u"نهاية",u"هذا",u"هذه",u"هناك",u"هو",u"هي",u"و",u"و6",u"واحد",u"واضاف",u"واضافت",u"واكد",u"وان",u"واوضح",u"وفي",u"وقال",u"وقالت",u"وقد",u"وقف",u"وكان",u"وكانت",u"ولا",u"ولم",u"ومن",u"وهو",u"وهي",u"يكون",u"يمكن",u"يوم"],u"bg":[u"а",u"автентичен",u"аз",u"ако",u"ала",u"бе",u"без",u"беше",u"би",u"бивш",u"бивша",u"бившо",u"бил",u"била",u"били",u"било",u"благодаря",u"близо",u"бъдат",u"бъде",u"бяха",u"в",u"вас",u"ваш",u"ваша",u"вероятно",u"вече",u"взема",u"ви",u"вие",u"винаги",u"внимава",u"време",u"все",u"всеки",u"всички",u"всичко",u"всяка",u"във",u"въпреки",u"върху",u"г",u"ги",u"главен",u"главна",u"главно",u"глас",u"го",u"година",u"години",u"годишен",u"д",u"да",u"дали",u"два",u"двама",u"двамата",u"две",u"двете",u"ден",u"днес",u"дни",u"до",u"добра",u"добре",u"добро",u"добър",u"докато",u"докога",u"дори",u"досега",u"доста",u"друг",u"друга",u"други",u"е",u"евтин",u"едва",u"един",u"една",u"еднаква",u"еднакви",u"еднакъв",u"едно",u"екип",u"ето",u"живот",u"за",u"забавям",u"зад",u"заедно",u"заради",u"засега",u"заспал",u"затова",u"защо",u"защото",u"и",u"из",u"или",u"им",u"има",u"имат",u"иска",u"й",u"каза",u"как",u"каква",u"какво",u"както",u"какъв",u"като",u"кога",u"когато",u"което",u"които",u"кой",u"който",u"колко",u"която",u"къде",u"където",u"към",u"лесен",u"лесно",u"ли",u"лош",u"м",u"май",u"малко",u"ме",u"между",u"мек",u"мен",u"месец",u"ми",u"много",u"мнозина",u"мога",u"могат",u"може",u"мокър",u"моля",u"момента",u"му",u"н",u"на",u"над",u"назад",u"най",u"направи",u"напред",u"например",u"нас",u"не",u"него",u"нещо",u"нея",u"ни",u"ние",u"никой",u"нито",u"нищо",u"но",u"нов",u"нова",u"нови",u"новина",u"някои",u"някой",u"няколко",u"няма",u"обаче",u"около",u"освен",u"особено",u"от",u"отгоре",u"отново",u"още",u"пак",u"по",u"повече",u"повечето",u"под",u"поне",u"поради",u"после",u"почти",u"прави",u"пред",u"преди",u"през",u"при",u"пък",u"първата",u"първи",u"първо",u"пъти",u"равен",u"равна",u"с",u"са",u"сам",u"само",u"се",u"сега",u"си",u"син",u"скоро",u"след",u"следващ",u"сме",u"смях",u"според",u"сред",u"срещу",u"сте",u"съм",u"със",u"също",u"т",u"т.н.",u"тази",u"така",u"такива",u"такъв",u"там",u"твой",u"те",u"тези",u"ти",u"то",u"това",u"тогава",u"този",u"той",u"толкова",u"точно",u"три",u"трябва",u"тук",u"тъй",u"тя",u"тях",u"у",u"утре",u"харесва",u"хиляди",u"ч",u"часа",u"че",u"често",u"чрез",u"ще",u"щом",u"юмрук",u"я",u"як"],u"bn":[u"অনেক",u"অন্য",u"অবশ্য",u"আগে",u"আছে",u"আজ",u"আবার",u"আমরা",u"আমাদের",u"আর",u"ই",u"উত্তর",u"উপর",u"উপরে",u"এ",u"এই",u"এক্",u"এখন",u"এত",u"এব",u"এমন",u"এমনি",u"এর",u"এস",u"এসে",u"ও",u"ওই",u"কমনে",u"করা",u"করে",u"কাছে",u"কাজ",u"কাজে",u"কারণ",u"কি",u"কিছু",u"কে",u"কেউ",u"কেখা",u"কেন",u"কোটি",u"কোনো",u"কয়েক",u"খুব",u"গিয়ে",u"গেল",u"চার",u"চালু",u"চেষ্টা",u"ছিল",u"জানা",u"জ্নজন",u"টি",u"তখন",u"তবে",u"তা",u"তাই",u"তো",u"থাকা",u"থেকে",u"দিন",u"দু",u"দুই",u"দেওয়া",u"ধামার",u"নতুন",u"না",u"নাগাদ",u"নিয়ে",u"নেওয়া",u"নয়",u"পর",u"পরে",u"পাচ",u"পি",u"পেয়্র্",u"প্রতি",u"প্রথম",u"প্রযন্ত",u"প্রাথমিক",u"প্রায়",u"বক্তব্য",u"বন",u"বলা",u"বলে",u"বলেন",u"বহু",u"বা",u"বি",u"বিভিন্ন",u"বেশ",u"বেশি",u"মতো",u"মধ্যে",u"মনে",u"যখন",u"যদি",u"যা",u"যাওয়া",u"যে",u"র",u"রকম",u"লক্ষ",u"শুধু",u"শুরু",u"সঙ্গে",u"সব",u"সহ",u"সাধারণ",u"সামনে",u"সি",u"সে",u"সেই",u"হতে",u"হাজার",u"হয়"],u"fa":[u"آباد",u"آره",u"آری",u"آمد",u"آمده",u"آن",u"آنان",u"آنجا",u"آنكه",u"آنها",u"آنچه",u"آورد",u"آورده",u"آيد",u"آیا",u"اثرِ",u"از",u"است",u"استفاده",u"اش",u"اكنون",u"البته",u"البتّه",u"ام",u"اما",u"امروز",u"امسال",u"اند",u"انکه",u"او",u"اول",u"اي",u"ايشان",u"ايم",u"اين",u"اينكه",u"اگر",u"با",u"بار",u"بارة",u"باره",u"باشد",u"باشند",u"باشيم",u"بالا",u"بالایِ",u"بايد",u"بدون",u"بر",u"برابرِ",u"براساس",u"براي",u"برایِ",u"برخوردار",u"برخي",u"برداري",u"بروز",u"بسيار",u"بسياري",u"بعد",u"بعری",u"بعضي",u"بلكه",u"بله",u"بلکه",u"بلی",u"بنابراين",u"بندي",u"به",u"بهترين",u"بود",u"بودن",u"بودند",u"بوده",u"بي",u"بيست",u"بيش",u"بيشتر",u"بيشتري",u"بين",u"بی",u"بیرونِ",u"تا",u"تازه",u"تاكنون",u"تان",u"تحت",u"تر",u"ترين",u"تمام",u"تمامي",u"تنها",u"تواند",u"توانند",u"توسط",u"تولِ",u"تویِ",u"جا",u"جاي",u"جايي",u"جدا",u"جديد",u"جريان",u"جز",u"جلوگيري",u"جلویِ",u"حتي",u"حدودِ",u"حق",u"خارجِ",u"خدمات",u"خواست",u"خواهد",u"خواهند",u"خواهيم",u"خود",u"خويش",u"خیاه",u"داد",u"دادن",u"دادند",u"داده",u"دارد",u"دارند",u"داريم",u"داشت",u"داشتن",u"داشتند",u"داشته",u"دانست",u"دانند",u"در",u"درباره",u"دنبالِ",u"ده",u"دهد",u"دهند",u"دو",u"دوم",u"ديده",u"ديروز",u"ديگر",u"ديگران",u"ديگري",u"دیگر",u"را",u"راه",u"رفت",u"رفته",u"روب",u"روزهاي",u"روي",u"رویِ",u"ريزي",u"زياد",u"زير",u"زيرا",u"زیرِ",u"سابق",u"ساخته",u"سازي",u"سراسر",u"سریِ",u"سعي",u"سمتِ",u"سوم",u"سوي",u"سویِ",u"سپس",u"شان",u"شايد",u"شد",u"شدن",u"شدند",u"شده",u"شش",u"شما",u"شناسي",u"شود",u"شوند",u"صورت",u"ضدِّ",u"ضمن",u"طبقِ",u"طريق",u"طور",u"طي",u"عقبِ",u"علّتِ",u"عنوانِ",u"غير",u"فقط",u"فكر",u"فوق",u"قابل",u"قبل",u"قصدِ",u"كرد",u"كردم",u"كردن",u"كردند",u"كرده",u"كسي",u"كل",u"كمتر",u"كند",u"كنم",u"كنند",u"كنيد",u"كنيم",u"كه",u"لطفاً",u"ما",u"مان",u"مانند",u"مانندِ",u"مثل",u"مثلِ",u"مختلف",u"مدّتی",u"مردم",u"مرسی",u"مقابل",u"من",u"مورد",u"مي",u"ميليارد",u"ميليون",u"مگر",u"ناشي",u"نام",u"نبايد",u"نبود",u"نخست",u"نخستين",u"نخواهد",u"ندارد",u"ندارند",u"نداشته",u"نزديك",u"نزدِ",u"نزدیکِ",u"نشان",u"نشده",u"نظير",u"نكرده",u"نمايد",u"نمي",u"نه",u"نوعي",u"نيز",u"نيست",u"ها",u"هاي",u"هايي",u"هر",u"هرگز",u"هزار",u"هست",u"هستند",u"هستيم",u"هفت",u"هم",u"همان",u"همه",u"همواره",u"همين",u"همچنان",u"همچنين",u"همچون",u"همین",u"هنوز",u"هنگام",u"هنگامِ",u"هنگامی",u"هيچ",u"هیچ",u"و",u"وسطِ",u"وقتي",u"وقتیکه",u"ولی",u"وي",u"وگو",u"يا",u"يابد",u"يك",u"يكديگر",u"يكي",u"ّه",u"پاعینِ",u"پس",u"پنج",u"پيش",u"پیش",u"پیشِ",u"چرا",u"چطور",u"چند",u"چندین",u"چنين",u"چه",u"چهار",u"چون",u"چيزي",u"چگونه",u"چیز",u"چیزی",u"چیست",u"کجا",u"کجاست",u"کدام",u"کس",u"کسی",u"کنارِ",u"که",u"کَی",u"کی",u"گذاري",u"گذاشته",u"گردد",u"گرفت",u"گرفته",u"گروهي",u"گفت",u"گفته",u"گويد",u"گويند",u"گيرد",u"گيري",u"یا",u"یک"],u"hi":[u"अंदर",u"अत",u"अदि",u"अप",u"अपना",u"अपनि",u"अपनी",u"अपने",u"अभि",u"अभी",u"आदि",u"आप",u"इंहिं",u"इंहें",u"इंहों",u"इतयादि",u"इत्यादि",u"इन",u"इनका",u"इन्हीं",u"इन्हें",u"इन्हों",u"इस",u"इसका",u"इसकि",u"इसकी",u"इसके",u"इसमें",u"इसि",u"इसी",u"इसे",u"उंहिं",u"उंहें",u"उंहों",u"उन",u"उनका",u"उनकि",u"उनकी",u"उनके",u"उनको",u"उन्हीं",u"उन्हें",u"उन्हों",u"उस",u"उसके",u"उसि",u"उसी",u"उसे",u"एक",u"एवं",u"एस",u"एसे",u"ऐसे",u"ओर",u"और",u"कइ",u"कई",u"कर",u"करता",u"करते",u"करना",u"करने",u"करें",u"कहते",u"कहा",u"का",u"काफि",u"काफ़ी",u"कि",u"किंहें",u"किंहों",u"कितना",u"किन्हें",u"किन्हों",u"किया",u"किर",u"किस",u"किसि",u"किसी",u"किसे",u"की",u"कुछ",u"कुल",u"के",u"को",u"कोइ",u"कोई",u"कोन",u"कोनसा",u"कौन",u"कौनसा",u"गया",u"घर",u"जब",u"जहाँ",u"जहां",u"जा",u"जिंहें",u"जिंहों",u"जितना",u"जिधर",u"जिन",u"जिन्हें",u"जिन्हों",u"जिस",u"जिसे",u"जीधर",u"जेसा",u"जेसे",u"जैसा",u"जैसे",u"जो",u"तक",u"तब",u"तरह",u"तिंहें",u"तिंहों",u"तिन",u"तिन्हें",u"तिन्हों",u"तिस",u"तिसे",u"तो",u"था",u"थि",u"थी",u"थे",u"दबारा",u"दवारा",u"दिया",u"दुसरा",u"दुसरे",u"दूसरे",u"दो",u"द्वारा",u"न",u"नहिं",u"नहीं",u"ना",u"निचे",u"निहायत",u"नीचे",u"ने",u"पर",u"पहले",u"पुरा",u"पूरा",u"पे",u"फिर",u"बनि",u"बनी",u"बहि",u"बही",u"बहुत",u"बाद",u"बाला",u"बिलकुल",u"भि",u"भितर",u"भी",u"भीतर",u"मगर",u"मानो",u"मे",u"में",u"यदि",u"यह",u"यहाँ",u"यहां",u"यहि",u"यही",u"या",u"यिह",u"ये",u"रखें",u"रवासा",u"रहा",u"रहे",u"ऱ्वासा",u"लिए",u"लिये",u"लेकिन",u"व",u"वगेरह",u"वरग",u"वर्ग",u"वह",u"वहाँ",u"वहां",u"वहिं",u"वहीं",u"वाले",u"वुह",u"वे",u"वग़ैरह",u"संग",u"सकता",u"सकते",u"सबसे",u"सभि",u"सभी",u"साथ",u"साबुत",u"साभ",u"सारा",u"से",u"सो",u"हि",u"ही",u"हुअ",u"हुआ",u"हुइ",u"हुई",u"हुए",u"हे",u"हें",u"है",u"हैं",u"हो",u"होता",u"होति",u"होती",u"होते",u"होना",u"होने"],u"mr":[u"अधिक",u"अनेक",u"अशी",u"असलयाचे",u"असलेल्या",u"असा",u"असून",u"असे",u"आज",u"आणि",u"आता",u"आपल्या",u"आला",u"आली",u"आले",u"आहे",u"आहेत",u"एक",u"एका",u"कमी",u"करणयात",u"करून",u"का",u"काम",u"काय",u"काही",u"किवा",u"की",u"केला",u"केली",u"केले",u"कोटी",u"गेल्या",u"घेऊन",u"जात",u"झाला",u"झाली",u"झाले",u"झालेल्या",u"टा",u"डॉ",u"तर",u"तरी",u"तसेच",u"ता",u"ती",u"तीन",u"ते",u"तो",u"त्या",u"त्याचा",u"त्याची",u"त्याच्या",u"त्याना",u"त्यानी",u"त्यामुळे",u"त्री",u"दिली",u"दोन",u"न",u"नाही",u"निर्ण्य",u"पण",u"पम",u"परयतन",u"पाटील",u"म",u"मात्र",u"माहिती",u"मी",u"मुबी",u"म्हणजे",u"म्हणाले",u"म्हणून",u"या",u"याचा",u"याची",u"याच्या",u"याना",u"यानी",u"येणार",u"येत",u"येथील",u"येथे",u"लाख",u"व",u"व्यकत",u"सर्व",u"सागित्ले",u"सुरू",u"हजार",u"हा",u"ही",u"हे",u"होणार",u"होत",u"होता",u"होती",u"होते"],u"ro":[u"acea",u"aceasta",u"această",u"aceea",u"acei",u"aceia",u"acel",u"acela",u"acele",u"acelea",u"acest",u"acesta",u"aceste",u"acestea",u"aceşti",u"aceştia",u"acolo",u"acord",u"acum",u"ai",u"aia",u"aibă",u"aici",u"al",u"ale",u"alea",u"altceva",u"altcineva",u"am",u"ar",u"are",u"asemenea",u"asta",u"astea",u"astăzi",u"asupra",u"au",u"avea",u"avem",u"aveţi",u"azi",u"aş",u"aşadar",u"aţi",u"bine",u"bucur",u"bună",u"ca",u"care",u"caut",u"ce",u"cel",u"ceva",u"chiar",u"cinci",u"cine",u"cineva",u"contra",u"cu",u"cum",u"cumva",u"curând",u"curînd",u"când",u"cât",u"câte",u"câtva",u"câţi",u"cînd",u"cît",u"cîte",u"cîtva",u"cîţi",u"că",u"căci",u"cărei",u"căror",u"cărui",u"către",u"da",u"dacă",u"dar",u"datorită",u"dată",u"dau",u"de",u"deci",u"deja",u"deoarece",u"departe",u"deşi",u"din",u"dinaintea",u"dintr-",u"dintre",u"doi",u"doilea",u"două",u"drept",u"după",u"dă",u"ea",u"ei",u"el",u"ele",u"eram",u"este",u"eu",u"eşti",u"face",u"fata",u"fi",u"fie",u"fiecare",u"fii",u"fim",u"fiu",u"fiţi",u"frumos",u"fără",u"graţie",u"halbă",u"iar",u"ieri",u"la",u"le",u"li",u"lor",u"lui",u"lângă",u"lîngă",u"mai",u"mea",u"mei",u"mele",u"mereu",u"meu",u"mi",u"mie",u"mine",u"mult",u"multă",u"mulţi",u"mulţumesc",u"mâine",u"mîine",u"mă",u"ne",u"nevoie",u"nici",u"nicăieri",u"nimeni",u"nimeri",u"nimic",u"nişte",u"noastre",u"noastră",u"noi",u"noroc",u"nostru",u"nouă",u"noştri",u"nu",u"opt",u"ori",u"oricare",u"orice",u"oricine",u"oricum",u"oricând",u"oricât",u"oricînd",u"oricît",u"oriunde",u"patra",u"patru",u"patrulea",u"pe",u"pentru",u"peste",u"pic",u"poate",u"pot",u"prea",u"prima",u"primul",u"prin",u"printr-",u"puţin",u"puţina",u"puţină",u"până",u"pînă",u"rog",u"sa",u"sale",u"sau",u"se",u"spate",u"spre",u"sub",u"sunt",u"suntem",u"sunteţi",u"sută",u"sînt",u"sîntem",u"sînteţi",u"să",u"săi",u"său",u"ta",u"tale",u"te",u"timp",u"tine",u"toate",u"toată",u"tot",u"totuşi",u"toţi",u"trei",u"treia",u"treilea",u"tu",u"tăi",u"tău",u"un",u"una",u"unde",u"undeva",u"unei",u"uneia",u"unele",u"uneori",u"unii",u"unor",u"unora",u"unu",u"unui",u"unuia",u"unul",u"vi",u"voastre",u"voastră",u"voi",u"vostru",u"vouă",u"voştri",u"vreme",u"vreo",u"vreun",u"vă",u"zece",u"zero",u"zi",u"zice",u"îi",u"îl",u"îmi",u"împotriva",u"în",u"înainte",u"înaintea",u"încotro",u"încât",u"încît",u"între",u"întrucât",u"întrucît",u"îţi",u"ăla",u"ălea",u"ăsta",u"ăstea",u"ăştia",u"şapte",u"şase",u"şi",u"ştiu",u"ţi",u"ţie"],u"en":[u"a",u"a's",u"able",u"about",u"above",u"according",u"accordingly",u"across",u"actually",u"after",u"afterwards",u"again",u"against",u"ain't",u"all",u"allow",u"allows",u"almost",u"alone",u"along",u"already",u"also",u"although",u"always",u"am",u"among",u"amongst",u"an",u"and",u"another",u"any",u"anybody",u"anyhow",u"anyone",u"anything",u"anyway",u"anyways",u"anywhere",u"apart",u"appear",u"appreciate",u"appropriate",u"are",u"aren't",u"around",u"as",u"aside",u"ask",u"asking",u"associated",u"at",u"available",u"away",u"awfully",u"b",u"be",u"became",u"because",u"become",u"becomes",u"becoming",u"been",u"before",u"beforehand",u"behind",u"being",u"believe",u"below",u"beside",u"besides",u"best",u"better",u"between",u"beyond",u"both",u"brief",u"but",u"by",u"c",u"c'mon",u"c's",u"came",u"can",u"can't",u"cannot",u"cant",u"cause",u"causes",u"certain",u"certainly",u"changes",u"clearly",u"co",u"com",u"come",u"comes",u"concerning",u"consequently",u"consider",u"considering",u"contain",u"containing",u"contains",u"corresponding",u"could",u"couldn't",u"course",u"currently",u"d",u"definitely",u"described",u"despite",u"did",u"didn't",u"different",u"do",u"does",u"doesn't",u"doing",u"don't",u"done",u"down",u"downwards",u"during",u"e",u"each",u"edu",u"eg",u"eight",u"either",u"else",u"elsewhere",u"enough",u"entirely",u"especially",u"et",u"etc",u"even",u"ever",u"every",u"everybody",u"everyone",u"everything",u"everywhere",u"ex",u"exactly",u"example",u"except",u"f",u"far",u"few",u"fifth",u"first",u"five",u"followed",u"following",u"follows",u"for",u"former",u"formerly",u"forth",u"four",u"from",u"further",u"furthermore",u"g",u"get",u"gets",u"getting",u"given",u"gives",u"go",u"goes",u"going",u"gone",u"got",u"gotten",u"greetings",u"h",u"had",u"hadn't",u"happens",u"hardly",u"has",u"hasn't",u"have",u"haven't",u"having",u"he",u"he's",u"hello",u"help",u"hence",u"her",u"here",u"here's",u"hereafter",u"hereby",u"herein",u"hereupon",u"hers",u"herself",u"hi",u"him",u"himself",u"his",u"hither",u"hopefully",u"how",u"howbeit",u"however",u"i",u"i'd",u"i'll",u"i'm",u"i've",u"ie",u"if",u"ignored",u"immediate",u"in",u"inasmuch",u"inc",u"indeed",u"indicate",u"indicated",u"indicates",u"inner",u"insofar",u"instead",u"into",u"inward",u"is",u"isn't",u"it",u"it'd",u"it'll",u"it's",u"its",u"itself",u"j",u"just",u"k",u"keep",u"keeps",u"kept",u"know",u"known",u"knows",u"l",u"last",u"lately",u"later",u"latter",u"latterly",u"least",u"less",u"lest",u"let",u"let's",u"like",u"liked",u"likely",u"little",u"look",u"looking",u"looks",u"ltd",u"m",u"mainly",u"many",u"may",u"maybe",u"me",u"mean",u"meanwhile",u"merely",u"might",u"more",u"moreover",u"most",u"mostly",u"much",u"must",u"my",u"myself",u"n",u"name",u"namely",u"nd",u"near",u"nearly",u"necessary",u"need",u"needs",u"neither",u"never",u"nevertheless",u"new",u"next",u"nine",u"no",u"nobody",u"non",u"none",u"noone",u"nor",u"normally",u"not",u"nothing",u"novel",u"now",u"nowhere",u"o",u"obviously",u"of",u"off",u"often",u"oh",u"ok",u"okay",u"old",u"on",u"once",u"one",u"ones",u"only",u"onto",u"or",u"other",u"others",u"otherwise",u"ought",u"our",u"ours",u"ourselves",u"out",u"outside",u"over",u"overall",u"own",u"p",u"particular",u"particularly",u"per",u"perhaps",u"placed",u"please",u"plus",u"possible",u"presumably",u"probably",u"provides",u"q",u"que",u"quite",u"qv",u"r",u"rather",u"rd",u"re",u"really",u"reasonably",u"regarding",u"regardless",u"regards",u"relatively",u"respectively",u"right",u"s",u"said",u"same",u"saw",u"say",u"saying",u"says",u"second",u"secondly",u"see",u"seeing",u"seem",u"seemed",u"seeming",u"seems",u"seen",u"self",u"selves",u"sensible",u"sent",u"serious",u"seriously",u"seven",u"several",u"shall",u"she",u"should",u"shouldn't",u"since",u"six",u"so",u"some",u"somebody",u"somehow",u"someone",u"something",u"sometime",u"sometimes",u"somewhat",u"somewhere",u"soon",u"sorry",u"specified",u"specify",u"specifying",u"still",u"sub",u"such",u"sup",u"sure",u"t",u"t's",u"take",u"taken",u"tell",u"tends",u"th",u"than",u"thank",u"thanks",u"thanx",u"that",u"that's",u"thats",u"the",u"their",u"theirs",u"them",u"themselves",u"then",u"thence",u"there",u"there's",u"thereafter",u"thereby",u"therefore",u"therein",u"theres",u"thereupon",u"these",u"they",u"they'd",u"they'll",u"they're",u"they've",u"think",u"third",u"this",u"thorough",u"thoroughly",u"those",u"though",u"three",u"through",u"throughout",u"thru",u"thus",u"to",u"together",u"too",u"took",u"toward",u"towards",u"tried",u"tries",u"truly",u"try",u"trying",u"twice",u"two",u"u",u"un",u"under",u"unfortunately",u"unless",u"unlikely",u"until",u"unto",u"up",u"upon",u"us",u"use",u"used",u"useful",u"uses",u"using",u"usually",u"uucp",u"v",u"value",u"various",u"very",u"via",u"viz",u"vs",u"w",u"want",u"wants",u"was",u"wasn't",u"way",u"we",u"we'd",u"we'll",u"we're",u"we've",u"welcome",u"well",u"went",u"were",u"weren't",u"what",u"what's",u"whatever",u"when",u"whence",u"whenever",u"where",u"where's",u"whereafter",u"whereas",u"whereby",u"wherein",u"whereupon",u"wherever",u"whether",u"which",u"while",u"whither",u"who",u"who's",u"whoever",u"whole",u"whom",u"whose",u"why",u"will",u"willing",u"wish",u"with",u"within",u"without",u"won't",u"wonder",u"would",u"wouldn't",u"x",u"y",u"yes",u"yet",u"you",u"you'd",u"you'll",u"you're",u"you've",u"your",u"yours",u"yourself",u"yourselves",u"z",u"zero"]}
